/*******************************************************************************
* 			Community Health Workers As Key Providers of Easy-to-Use
								Contraceptive Injectables:
						Experimental Evidence from Rural Burundi	           *
********************************************************************************
	REQUIRES: ${final}\qt_contraceptives.dta	
	CREATES:  ${figures}/Figure 2.png
			
				
	WRITEN BY:  Paula Spinola & Michele Andreottola
	
********************************************************************************
    PART 1: Figure 2
********************************************************************************/

use "${final}/qt_contraceptives.dta", clear

su sayana_asc if rand_group==0
su sayana_asc if rand_group==1
tab date if sayana_asc>0 & rand_group==1 // starts picking up among treatment group in Nov/22
tab date if sayana_asc>0 & rand_group==0 // shows up in very small quantities among control group

gen short_ = condom + postinor_hc
gen long_ = diu_hc + impl_hc 
gen cont_tot = sayana + dmpa_im + pill + short_ + long_

collapse (mean) sayana cont_tot, by(rand_group date)

twoway (line sayana date if rand_group==1, col(black) lpattern(shortdash)) (line sayana date if rand_group==0, col(black)), graphregion(color(white)) xlabel(720 "Jan/2020" 726 "Jul/2020" 732 "Jan/2021" 738 "Jul/2021" 744 "Jan/2022" 747 "{bf:Apr/2022}" 750 "{bf:Jul/2022}" 753 "{bf:Oct/2022}" 756 "{bf:Jan/2023}" 759 "{bf:Abr/2023}" 762 "{bf:Jul/2023}" 765 "{bf:Oct/2023}", angle(vertical) nogrid  labsize(small)) xline(747 753, lpattern(solid)  lcol(dimgray))  xtitle("") legend(off) ytitle("{bf: No. Sayana Press injections}", size(medsmall)) yscale(titlegap(3)) ylabel(0(15)75, angle(vertical) nogrid) text(72 750 "Theoretical" "training", place(c) size(vsmall)) text(79 753 "Pratical training", place(c) size(vsmall)) text(72 762 "Eligibility period", place(c) size(vsmall)) xscale(off) name(g_say, replace) // legend(order(1 "Treatment group" 2 "Control group") symxsize(6) region(col(none)) ring(0) pos(10) col(1) size(small))



// Total contraceptives
twoway (line cont_tot date if rand_group==1, col(black) lpattern(shortdash)) (line cont_tot date if rand_group==0, col(black)) , graphregion(color(white)) xlabel(720 "Jan/2020" 726 "Jul/2020" 732 "Jan/2021" 738 "Jul/2021" 744 "Jan/2022" 747 "{bf:Apr/2022}" 750 "{bf:Jul/2022}" 753 "{bf:Oct/2022}" 756 "{bf:Jan/2023}" 759 "{bf:Abr/2023}" 762 "{bf:Jul/2023}" 765 "{bf:Oct/2023}", angle(vertical) nogrid  labsize(small)) xline(747 753, lpattern(solid)  lcol(dimgray))   xtitle("") legend(order(1 "Treatment group" 2 "Control group") symxsize(6) region(col(none)) ring(0) pos(8) col(1) size(small)) ytitle("{bf: Total contraceptives dispensed}", size(medsmall)) yscale(titlegap(3)) ylabel(200(200)600, angle(vertical) nogrid) name(g_tot, replace) // text(600 750 "Theoretical" "training", place(c) size(vsmall)) text(650 753 "Pratical training", place(c) size(vsmall)) text(600 762 "Eligibility period", place(c) size(vsmall)) 

graph combine g_say g_tot, cols(1) graphregion(color(white)) 
graph export "${paper}/Figures/Figure 2.png", replace

clear







