/*******************************************************************************
* 			Community Health Workers As Key Providers of Easy-to-Use
								Contraceptive Injectables:
						Experimental Evidence from Rural Burundi	           *
********************************************************************************
	REQUIRES: ${cleaned}\covariates.dta	
			  ${final}\nfemcov_by_asc.dta
	CREATES:  ${tables}/Table1_Panel_A.xls
			  ${tables}/Table1_Panel_B.xls
			
				
	WRITEN BY:  Paula Spinola & Michele Andreottola
	
********************************************************************************
    PART 1: Panel A
********************************************************************************/

use "${cleaned}/covariates", clear

tab province
/*
   orgunitlevel2 |      Freq.     Percent        Cum.
-----------------+-----------------------------------
         Bubanza |         15       10.87       10.87
         Cankuzo |         20       14.49       25.36
        Cibitoke |         36       26.09       51.45
         Kirundo |         26       18.84       70.29
         Makamba |          5        3.62       73.91
         Muyinga |         36       26.09      100.00
-----------------+-----------------------------------
           Total |        138      100.00
*/

gen sh_TPS = (nTPS>0) if nTPS!=.
gen nTPS_cond = nTPS
replace nTPS_cond=. if nTPS==0 // values are conditional on having TPS capacity
 
su sh_TPS nTPS_cond nASC dist_district dist_commune pop popfem, sep(0)
/*
    Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
      sh_TPS |        138    .2753623     .448324          0          1
   nTPS_cond |         38           1           0          1          1
        nASC |        138    16.11594     9.62211          1         48
dist_distr~t |        138    27.47826    20.13549          0        102
dist_commune |        138    14.95399    10.09013          0         71
         pop |        138    15775.17    8563.694       3202      60281
      popfem |        138    3738.716    2029.596    758.874    14286.6
*/
su sh_TPS nTPS_cond nASC dist_district dist_commune pop popfem if rand_group==1, sep(0)
/*
    Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
      sh_TPS |         69    .3333333    .4748581          0          1
   nTPS_cond |         23           1           0          1          1
        nASC |         69    15.28986    9.376286          1         45
dist_distr~t |         69    30.11014    21.79599          0        102
dist_commune |         69    15.15072    9.335048          0         40
         pop |         69    15387.04    7465.112       3386      39457
      popfem |         69    3646.729    1769.231    802.482   9351.309
*/
su sh_TPS nTPS_cond nASC dist_district dist_commune pop popfem if rand_group==0, sep(0)
/*
    Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
      sh_TPS |         69    .2173913    .4154928          0          1
   nTPS_cond |         15           1           0          1          1
        nASC |         69    16.94203    9.860623          1         48
dist_distr~t |         69    24.84638    18.10291          0         98
dist_commune |         69    14.75725    10.85803          0         71
         pop |         69     16163.3    9576.983       3202      60281
      popfem |         69    3830.703    2269.745    758.874    14286.6
*/

ttest sh_TPS, by(rand_group) level(95) // -.115942 [-.2661575    .0342735]
ttest nTPS_cond, by(rand_group) level(95) // 0 [0 0]
ttest nASC, by(rand_group) level(95) // 1.652174 [-1.587216    4.891564]
ttest dist_district, by(rand_group) level(95) // -5.263768 [-12.00911     1.48157]
ttest dist_commune, by(rand_group) level(95) // -.3934783 [-3.802459    3.015503]
ttest pop, by(rand_group) level(95) // 776.2609 [-2114.569    3667.091]
ttest popfem, by(rand_group) level(95) // 183.9738 [-501.1528    869.1005]

fre rand_group
local balvars sh_TPS nTPS_cond nASC dist_district dist_commune pop popfem

preserve

	label var sh_TPS 		"% of health centers with HPO availability" 
	label var nTPS_cond 				"No. HPO (conditional on >0)" 
	label var nASC 			"No. CHW"
	label var dist_district	"Distance (in km) to local health authority"
	label var dist_commune 	"Distance (in km) to regional health authority"
	label var pop "Population"
	label var popfem "Childbearing-aged women" 
	
	*Generating balance table for new treatment assignment: turn into latex
	iebaltab `balvars', grpvar(rand_group) control(0) order(1 0)  total rowvarlabels grouplabels("0 Control @ 1 Treatment)")  stats(desc(sd) pair(diff)) savexlsx("${paper}/Tables/Table1_Panel_A.xls") replace 
restore

/********************************************************************************
    PART 2: Panel B ~~~ Pre-treatment (January/2020 - March/2022) 
********************************************************************************/

use "${final}/nfemcov_by_asc.dta", clear
merge 1:1 date health_cent_id using "${final}/qt_contraceptives.dta", nogenerate
gen nreferal_asc = new_referal_asc + old_referal_asc

keep if inrange(date,ym(2020,1),ym(2022,3))

gen short_ = condom + postinor_hc
gen long_ = diu_hc + impl_hc 
gen cont_tot = sayana + dmpa_im + pill + short_ + long_

* monthly average by health center
collapse (mean) cont_tot sayana dmpa_im condom pill postinor_hc impl_hc diu_hc nreferal_asc, by(health_cent_id province rand_group)

*iebaltab sayana dmpa_im condom pill postinor_hc impl_hc diu_hc, grpvar(rand_group) control(0) replace rowvarlabel savecsv("${results}\balance_table_pre") format(%4.2f) // SD are showing as negative instead of in parathesis in excel file

su sayana cont_tot, sep(0)
/*
    Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
      sayana |        138    8.173311    13.63152    .037037   100.1852
    cont_tot |        138    447.4255    328.5007   46.35714    1812.37
*/

su sayana cont_tot if rand_group==1, sep(0)
/*
    Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
      sayana |         69    8.473418    15.20082    .037037   100.1852
    cont_tot |         69    445.5514    305.1177   46.35714   1312.407
*/

su sayana cont_tot if rand_group==0, sep(0)
/*
    Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
      sayana |         69    7.873204    11.96334   .1481481   55.59259
    cont_tot |         69    449.2996    352.5739      68.95    1812.37
*/

ttest sayana, by(rand_group) level(95) // -.6002135 [-5.205421    4.004994]
ttest cont_tot, by(rand_group) level(95) // -3.748129 [-107.2563    114.7525]

fre rand_group
local balvars sayana cont_tot

preserve

	label var sayana 		"Sayana Press" 
	label var cont_tot 		"Any contraceptive dispensed" 
	
	*Generating balance table for new treatment assignment: turn into latex
	iebaltab `balvars', grpvar(rand_group) control(0) order(1 0)  total rowvarlabels grouplabels("0 Control @ 1 Treatment")  stats(desc(sd) pair(diff)) savexlsx("${paper}/Tables/Table1_Panel_B.xls") replace 
restore

