********************************************************************************
							*** Overall Effects ***
********************************************************************************

use "${final}/qt_contraceptives.dta", clear
merge m:1 health_cent_id using "${raw}/study sample/hc_treatment_status", keepusing(strata) nogen
merge m:1 health_cent_id using "${cleaned}/covariates", keepusing(d_rural dist_commune nTPS nASC nASC2 popfem PopfemPerASC) nogen

drop if date == ym(2023,12) // control group was treated from Dec/2023
display (138)*(12*3+11) // 6486 obs -> monthly obs for all 138 between Jan/2020-Dec/2023
count if sayana!=. // 6139 obs (95%) with non-missing obs on contraceptive methods

// aggregating alternative contraceptives according to protection horizon
gen short_ = condom + postinor_hc
gen long_ = diu_hc + impl_hc 
gen long_ret = diu_ret + impl_ret 
*gen long_net = diu_hc + impl_hc - diu_ret - impl_ret 

gen cont_tot = sayana + dmpa_im + pill + short_ + long_

gen period = (date >= ym(2022,4)) // post-intervention indicator (since start of training)
gen x = rand_group*period


label def period_l 0 "Pre" 1 "Post"
label val period period_l

areg sayana rand_group##period, cluster(health_cent_id) absorb(strata)
keep if e(sample)==1
* ~~~ Single period ------------------------------------------------------------
/*
cap erase "${tables}\Table2.xls"
cap erase "${tables}\Table2.txt"

local vars 1.rand_group#1.period 1.period 1.rand_group

foreach outcome in sayana newfem_sayana say_ren {
	areg `outcome' rand_group##period, cluster(health_cent_id) absorb(strata)
	su `outcome' if e(sample)==1 & period==0
	local y0mean_sample `r(mean)'
	su `outcome' if period==0
	local y0mean `r(mean)'
	outreg2 using "${tables}\Table2.xls", nocons dec(2) keep(`vars') sortvar(`vars') addstat("Mean Y0 sample", `y0mean_sample', "Mean Y0", `y0mean') adec(2)
}
*/
eststo clear 
local vars 1.rand_group#1.period 1.period 1.rand_group
foreach outcome2 in sayana sayana_hc sayana_tps sayana_asc cont_tot {
eststo `outcome2': areg `outcome2' rand_group##period, cluster(health_cent_id) absorb(strata)
qui su `outcome2' if e(sample)==1 & period==0
estadd scalar Mean= r(mean)
su dmpa_im if period==0
estadd scalar MeanY0= r(mean)
estadd scalar Within_R2= e(r2_w)
}
esttab sayana sayana_hc sayana_tps sayana_asc cont_tot using "${paper}/Tables/Table2A.csv",  noconstant keep(`vars') order(`vars') b(2) se r2 label star(* 0.10 ** 0.05 *** 0.01) mtitles("Total" "Health Center" "Home visit By HPO" "Home visit By CHW" "Any contraceptive dispensed") stats(N Mean, fmt(%9.0g %9.2f) labels("Observations" "Baseline mean")) replace



/*
cap erase "${tables}\Table4.xls"
cap erase "${tables}\Table4.txt"

foreach outcome2 in dmpa_im pill short_ long_ long_ret {
	areg `outcome2' rand_group##period, cluster(health_cent_id) absorb(strata)
	su `outcome2' if e(sample)==1 & period==0
	local y0mean_sample `r(mean)'
	su `outcome2' if period==0
	local y0mean `r(mean)'
	outreg2 using "${tables}\Table4.xls", nocons dec(2) keep(`vars') sortvar(`vars') addstat("Mean Y0 sample", `y0mean_sample', "Mean Y0", `y0mean') adec(2)
*/


eststo clear
local vars 1.rand_group#1.period 1.period 1.rand_group
foreach outcome2 in dmpa_im pill short_ long_ long_ret {
eststo `outcome2': areg `outcome2' rand_group##period, cluster(health_cent_id) absorb(strata)
qui su `outcome2' if e(sample)==1 & period==0
estadd scalar Mean= r(mean)
su dmpa_im if period==0
estadd scalar MeanY0= r(mean)
estadd scalar Within_R2= e(r2_w)
}
esttab dmpa_im pill short_ long_ long_ret using "${paper}/Tables/Table2B.csv",  noconstant keep(`vars') order(`vars') b(2) se r2 label star(* 0.10 ** 0.05 *** 0.01) mtitles("DMPA-IM" "Monthly Pill" "Condom & Morning Pill" "Implants & IUD introduced" "Implants & IUD removed") stats(N Mean, fmt(%9.0g %9.2f) labels("Observations" "Baseline-mean")) replace

eststo clear
set seed 2024
// Adjusting for multiple hypothesis testing (outcomes: all alternative contraceptives)
local ind_var x rand_group period
local reg_opt cluster(health_cent_id) absorb(strata)

rwolf2 (areg dmpa_im `ind_var', `reg_opt') ///
(areg pill `ind_var', `reg_opt') ///
(areg short_ `ind_var', `reg_opt') ///
(areg long_ `ind_var', `reg_opt') ///
(areg long_ret `ind_var', `reg_opt'), /// 
indepvars(x,x,x,x,x) reps(250) 

esttab using "${paper}/Tables/Romano-Wolf P values.csv", stats(rw_dmpa_im_x  rw_pill_x rw_short__x rw_long__x rw_long_ret_x,fmt(%9.3f %9.3f %9.3f %9.3f %9.3f) labels("DMPA-IM" "Monthly Pill" "Condom & Morning Pill" "Implants & IUD introduced" "Implants & IUD removed")) mtitles(" Romano-Wolf p-value") replace

/* We Strata is added coeff of Pill and Removal of devices is statistical sig at 10% (p-value= 0.0637)

------------------------------------------------------------------------------
                | Model p-value    Resample p-value    Romano-Wolf p-value
----------------+-------------------------------------------------------------
dmpa_im         |     
              x |     0.3921             0.0876              0.1673
------------------------------------------------------------------------------
pill            |     
              x |     0.1850             0.0159              0.0598
------------------------------------------------------------------------------
short_          |     
              x |     0.7175             0.4343              0.4343
------------------------------------------------------------------------------
long_           |     
              x |     0.0108             0.0040              0.0040
------------------------------------------------------------------------------
long_ret        |     
              x |     0.2801             0.0558              0.1315
------------------------------------------------------------------------------

*/
*/




