
********************************************************************************
						* Sayana Press & Implants/IUD *
********************************************************************************

// Sayana Press ----------------------------------------------------------------
use "${final}/qt_contraceptives.dta", clear
merge m:1 health_cent_id using "${raw}/study sample/hc_treatment_status", keepusing(strata) nogen

drop if date == ym(2023,12) // control group was treated from Dec/2023


* ~~~ Reference period as the entire pre-intervention period (jan 2020 until mar 2022)
gen date2 = date
replace date2 = 746 if date2<747

areg sayana rand_group##date2, absorb(strata) cluster(health_cent_id) level(95)

preserve

matrix A = r(table)

matrix colnames A = a b c d e f g h i l m l n o p q r s t u v w z aa bb cc dd ee ff gg hh ii ll mm nn oo pp qq rr ss tt uu vv ww zz aaa bbb ccc ddd eee fff ggg hhh iii lll mmm nnn ooo ppp qqq rrr sss ttt uuu vvv www

// get original row names of matrix (and row count)
local rownames : rowfullnames A
local c : word count `rownames'

// get original column names of matrix and substitute out _cons
local names : colfullnames A
*local newnames : subinstr local names "_cons" "cons", word

// rename columns of matrix
*matrix colnames A = `newnames'

// convert to dataset
clear
svmat A

// add matrix row names to dataset
gen rownames = ""
forvalues i = 1/`c' {
    replace rownames = "`:word `i' of `rownames''" in `i'
}

keep A46 - A65 rownames

// check
order rownames
rename rownames _varname
xpose , clear varname
drop _varname
gen ym = _n+746
gen method_num = 1
gen method = "Sayana"

keep b se ll ul ym method_num method
rename ll ci95_lower 
rename ul ci95_upper

tempfile sayana_95
save `sayana_95'

restore

/*
test 1.rand_group#764.date 1.rand_group#765.date 1.rand_group#766.date
test 1.rand_group#763.date 1.rand_group#764.date 1.rand_group#765.date 1.rand_group#766.date
test 1.rand_group#762.date 1.rand_group#763.date 1.rand_group#764.date 1.rand_group#765.date 1.rand_group#766.date

test 1.rand_group#754.date 1.rand_group#755.date 1.rand_group#756.date 1.rand_group#757.date 1.rand_group#758.date 1.rand_group#759.date 1.rand_group#760.date 1.rand_group#761.date 1.rand_group#762.date 1.rand_group#763.date 1.rand_group#764.date 1.rand_group#765.date 1.rand_group#766.date
*/

/*
rand_group#date |
  Treatment#747  |    3.71183   5.222171     0.71   0.478    -6.614653    14.03831
  Treatment#748  |   12.05966   4.010585     3.01   0.003     4.129001    19.99031
  Treatment#749  |   7.494439   3.879402     1.93   0.055    -.1768117    15.16569
  Treatment#750  |   5.157937   3.575471     1.44   0.151    -1.912311    12.22819
  Treatment#751  |   12.27705    3.49506     3.51   0.001     5.365807    19.18829
  Treatment#752  |   10.91717   4.008417     2.72   0.007     2.990803    18.84354
  Treatment#753  |   43.28933   6.306172     6.86   0.000     30.81931    55.75935
  Treatment#754  |    15.9496   5.433861     2.94   0.004     5.204509    26.69468
  Treatment#755  |   10.83796    4.15998     2.61   0.010     2.611884    19.06403
  Treatment#756  |   15.84453   4.139058     3.83   0.000     7.659825    24.02923
  Treatment#757  |   2.866348   4.812742     0.60   0.552    -6.650519    12.38321
  Treatment#758  |   8.706627   5.433681     1.60   0.111    -2.038104    19.45136
  Treatment#759  |    23.5958   9.410797     2.51   0.013     4.986592      42.205
  Treatment#760  |   9.007438   5.801009     1.55   0.123    -2.463659    20.47854
  Treatment#761  |   18.17572   5.890557     3.09   0.002     6.527549    29.82389
  Treatment#762  |   16.15616   5.993869     2.70   0.008     4.303694    28.00862
  Treatment#763  |   7.584598   5.542862     1.37   0.173     -3.37603    18.54523
  Treatment#764  |   7.010648   5.225004     1.34   0.182    -3.321439    17.34273
  Treatment#765  |   6.333986   4.903053     1.29   0.199    -3.361464    16.02944
  Treatment#766  |   16.52608   10.80047     1.53   0.128    -4.831096    37.88326
*/


* ~~~ Implants/IUD -------------------------------------------------------------
gen long_ = diu_hc + impl_hc 

areg long_ rand_group##date2, absorb(strata) cluster(health_cent_id) level(95)

preserve

matrix A = r(table)

matrix colnames A = a b c d e f g h i l m l n o p q r s t u v w z aa bb cc dd ee ff gg hh ii ll mm nn oo pp qq rr ss tt uu vv ww zz aaa bbb ccc ddd eee fff ggg hhh iii lll mmm nnn ooo ppp qqq rrr sss ttt uuu vvv www

// get original row names of matrix (and row count)
local rownames : rowfullnames A
local c : word count `rownames'

// get original column names of matrix and substitute out _cons
local names : colfullnames A
*local newnames : subinstr local names "_cons" "cons", word

// rename columns of matrix
*matrix colnames A = `newnames'

// convert to dataset
clear
svmat A

// add matrix row names to dataset
gen rownames = ""
forvalues i = 1/`c' {
    replace rownames = "`:word `i' of `rownames''" in `i'
}

keep A46 - A65 rownames

// check
order rownames
rename rownames _varname
xpose , clear varname
drop _varname
gen ym = _n+746
gen method_num = 1
gen method = "Devices"

keep b se ll ul ym method_num method
rename ll ci95_lower 
rename ul ci95_upper

tempfile devices_95
save `devices_95'

restore
/*
  Treatment#747  |  -4.021702   1.290899    -3.12   0.002    -6.574365   -1.469039
  Treatment#748  |  -2.210108   1.530909    -1.44   0.151    -5.237376    .8171592
  Treatment#749  |  -.9492387   2.420896    -0.39   0.696    -5.736394    3.837917
  Treatment#750  |  -3.304899   2.674116    -1.24   0.219     -8.59278    1.982981
  Treatment#751  |  -5.514456   1.474677    -3.74   0.000    -8.430528   -2.598384
  Treatment#752  |  -4.021778   1.968748    -2.04   0.043    -7.914841   -.1287148
  Treatment#753  |  -3.154353   1.396645    -2.26   0.025    -5.916123   -.3925836
  Treatment#754  |  -3.381916   1.231562    -2.75   0.007    -5.817245   -.9465867
  Treatment#755  |  -4.549458   1.281337    -3.55   0.001    -7.083214   -2.015703
  Treatment#756  |  -2.816844   1.419696    -1.98   0.049    -5.624195   -.0094932
  Treatment#757  |  -1.661004   1.237991    -1.34   0.182    -4.109046    .7870366
  Treatment#758  |   -1.75478   1.653228    -1.06   0.290    -5.023925    1.514365
  Treatment#759  |  -1.407759   1.418039    -0.99   0.323    -4.211834    1.396316
  Treatment#760  |  -2.693915   2.510741    -1.07   0.285    -7.658732    2.270903
  Treatment#761  |  -1.578061   2.110783    -0.75   0.456    -5.751989    2.595867
  Treatment#762  |  -3.800671   1.870596    -2.03   0.044    -7.499646   -.1016971
  Treatment#763  |    -4.4354   1.669817    -2.66   0.009    -7.737348   -1.133452
  Treatment#764  |  -1.706196   2.023508    -0.84   0.401    -5.707544    2.295152
  Treatment#765  |  -.0832972   1.608416    -0.05   0.959    -3.263829    3.097235
  Treatment#766  |   .4612082   2.375802     0.19   0.846    -4.236777    5.159193
*/

* ~~~ Condoms -------------------------------------------------------------
gen short_ = condom + postinor_hc
areg short_ rand_group##date2, absorb(strata) cluster(health_cent_id) level(95)

preserve

matrix A = r(table)

matrix colnames A = a b c d e f g h i l m l n o p q r s t u v w z aa bb cc dd ee ff gg hh ii ll mm nn oo pp qq rr ss tt uu vv ww zz aaa bbb ccc ddd eee fff ggg hhh iii lll mmm nnn ooo ppp qqq rrr sss ttt uuu vvv www

// get original row names of matrix (and row count)
local rownames : rowfullnames A
local c : word count `rownames'

// get original column names of matrix and substitute out _cons
local names : colfullnames A
*local newnames : subinstr local names "_cons" "cons", word

// rename columns of matrix
*matrix colnames A = `newnames'

// convert to dataset
clear
svmat A

// add matrix row names to dataset
gen rownames = ""
forvalues i = 1/`c' {
    replace rownames = "`:word `i' of `rownames''" in `i'
}

keep A46 - A65 rownames

// check
order rownames
rename rownames _varname
xpose , clear varname
drop _varname
gen ym = _n+746
gen method_num = 1
gen method = "Condom"

keep b se ll ul ym method_num method
rename ll ci95_lower 
rename ul ci95_upper

tempfile condom_95
save `condom_95'
restore
/*
  Treatment#747  |   -18.7496   50.68149    -0.37   0.712    -118.9688    81.46955
  Treatment#748  |    41.4388   64.82652     0.64   0.524    -86.75117    169.6288
  Treatment#749  |   -51.3583   49.18524    -1.04   0.298    -148.6187    45.90213
  Treatment#750  |   7.788877   73.25312     0.11   0.915    -137.0641    152.6419
  Treatment#751  |   16.33735   52.96883     0.31   0.758    -88.40486    121.0796
  Treatment#752  |   18.46835   47.69165     0.39   0.699    -75.83861    112.7753
  Treatment#753  |   131.7695   149.6122     0.88   0.380    -164.0784    427.6174
  Treatment#754  |   9.695374   52.10998     0.19   0.853    -93.34853    112.7393
  Treatment#755  |   13.74922   68.98803     0.20   0.842    -122.6699    150.1683
  Treatment#756  |  -99.16881   70.26868    -1.41   0.160    -238.1203    39.78268
  Treatment#757  |   83.16188   47.88292     1.74   0.085    -11.52331    177.8471
  Treatment#758  |  -70.23257   66.53694    -1.06   0.293    -201.8048    61.33966
  Treatment#759  |   40.85696   59.68112     0.68   0.495    -77.15835    158.8723
  Treatment#760  |   -37.1804   56.04881    -0.66   0.508    -148.0131    73.65228
  Treatment#761  |   30.21281   64.03552     0.47   0.638    -96.41301    156.8386
  Treatment#762  |   49.85132   58.98468     0.85   0.399    -66.78683    166.4895
  Treatment#763  |   57.52859   53.22795     1.08   0.282    -47.72601    162.7832
  Treatment#764  |   82.91816   74.91958     1.11   0.270    -65.23016    231.0665
  Treatment#765  |  -31.90741   84.63666    -0.38   0.707    -199.2706    135.4558
  Treatment#766  |  -43.98293   95.53027    -0.46   0.646    -232.8875    144.9216
*/

* ~~~ Pill -------------------------------------------------------------

areg pill rand_group##date2, absorb(strata) cluster(health_cent_id) level(95)

preserve

matrix A = r(table)

matrix colnames A = a b c d e f g h i l m l n o p q r s t u v w z aa bb cc dd ee ff gg hh ii ll mm nn oo pp qq rr ss tt uu vv ww zz aaa bbb ccc ddd eee fff ggg hhh iii lll mmm nnn ooo ppp qqq rrr sss ttt uuu vvv www

// get original row names of matrix (and row count)
local rownames : rowfullnames A
local c : word count `rownames'

// get original column names of matrix and substitute out _cons
local names : colfullnames A
*local newnames : subinstr local names "_cons" "cons", word

// rename columns of matrix
*matrix colnames A = `newnames'

// convert to dataset
clear
svmat A

// add matrix row names to dataset
gen rownames = ""
forvalues i = 1/`c' {
    replace rownames = "`:word `i' of `rownames''" in `i'
}

keep A46 - A65 rownames

// check
order rownames
rename rownames _varname
xpose , clear varname
drop _varname
gen ym = _n+746
gen method_num = 1
gen method = "Pill"

keep b se ll ul ym method_num method
rename ll ci95_lower 
rename ul ci95_upper

tempfile pill_95
save `pill_95'
restore
/*
  Treatment#747  |   -9.59713   7.373554    -1.30   0.195    -24.17783    4.983566
  Treatment#748  |    .011566   7.622958     0.00   0.999    -15.06231    15.08544
  Treatment#749  |  -6.075391   6.887416    -0.88   0.379    -19.69478       7.544
  Treatment#750  |  -4.754773   8.817544    -0.54   0.591    -22.19086    12.68131
  Treatment#751  |   -7.49568   6.481246    -1.16   0.249     -20.3119    5.320537
  Treatment#752  |  -12.97349   5.263435    -2.46   0.015    -23.38157   -2.565406
  Treatment#753  |   .4086151   7.175433     0.06   0.955    -13.78031    14.59754
  Treatment#754  |  -6.672045   9.176846    -0.73   0.468    -24.81863    11.47454
  Treatment#755  |  -8.148938   8.243298    -0.99   0.325    -24.44949    8.151616
  Treatment#756  |  -3.822526   9.724911    -0.39   0.695    -23.05287    15.40782
  Treatment#757  |  -2.006859   6.679261    -0.30   0.764    -15.21464    11.20092
  Treatment#758  |  -12.32076   5.616534    -2.19   0.030    -23.42707   -1.214449
  Treatment#759  |  -5.959869   5.778756    -1.03   0.304    -17.38696    5.467223
  Treatment#760  |  -5.934617   6.714616    -0.88   0.378    -19.21231    7.343074
  Treatment#761  |  -13.03752   6.743274    -1.93   0.055    -26.37188    .2968448
  Treatment#762  |  -15.10454   6.981077    -2.16   0.032    -28.90914   -1.299938
  Treatment#763  |  -92.73976   79.35753    -1.17   0.245    -249.6638     64.1843
  Treatment#764  |    47.2175   56.13537     0.84   0.402    -63.78633    158.2213
  Treatment#765  |  -3.227102   8.901236    -0.36   0.718    -20.82868    14.37448
  Treatment#766  |  -9.700878   7.646795    -1.27   0.207    -24.82189    5.420132
*/

* ~~~ DMPA-IM ------------------------------------------------------------------
areg dmpa_im rand_group##date2, absorb(strata) cluster(health_cent_id) level(95)

preserve

matrix A = r(table)

matrix colnames A = a b c d e f g h i l m l n o p q r s t u v w z aa bb cc dd ee ff gg hh ii ll mm nn oo pp qq rr ss tt uu vv ww zz aaa bbb ccc ddd eee fff ggg hhh iii lll mmm nnn ooo ppp qqq rrr sss ttt uuu vvv www

// get original row names of matrix (and row count)
local rownames : rowfullnames A
local c : word count `rownames'

// get original column names of matrix and substitute out _cons
local names : colfullnames A
*local newnames : subinstr local names "_cons" "cons", word

// rename columns of matrix
*matrix colnames A = `newnames'

// convert to dataset
clear
svmat A

// add matrix row names to dataset
gen rownames = ""
forvalues i = 1/`c' {
    replace rownames = "`:word `i' of `rownames''" in `i'
}

keep A46 - A65 rownames

// check
order rownames
rename rownames _varname
xpose , clear varname
drop _varname
gen ym = _n+746
gen method_num = 1
gen method = "DMPA-IM"

keep b se ll ul ym method_num method
rename ll ci95_lower 
rename ul ci95_upper

tempfile dmpa_im_95
save `dmpa_im_95'
restore
/*
  Treatment#747  |  -.7130535   6.661939    -0.11   0.915    -13.88658    12.46047
  Treatment#748  |  -10.75653   6.011635    -1.79   0.076    -22.64413    1.131063
  Treatment#749  |   -9.80001   6.745082    -1.45   0.149    -23.13794    3.537925
  Treatment#750  |  -1.688315     6.4518    -0.26   0.794    -14.44631    11.06968
  Treatment#751  |  -7.582619   6.907907    -1.10   0.274    -21.24253    6.077291
  Treatment#752  |  -5.611475   6.871542    -0.82   0.416    -19.19948    7.976526
  Treatment#753  |  -26.59538   8.308785    -3.20   0.002    -43.02543   -10.16532
  Treatment#754  |  -9.826917   6.902981    -1.42   0.157    -23.47709    3.823253
  Treatment#755  |  -4.089967   7.428466    -0.55   0.583    -18.77925    10.59931
  Treatment#756  |  -5.020681   11.38246    -0.44   0.660    -27.52871    17.48735
  Treatment#757  |   4.087673   7.161344     0.57   0.569    -10.07339    18.24874
  Treatment#758  |  -16.31842   12.38949    -1.32   0.190    -40.81779    8.180955
  Treatment#759  |    .311877   9.579178     0.03   0.974    -18.63029    19.25404
  Treatment#760  |   .9897036   10.41552     0.10   0.924    -19.60626    21.58567
  Treatment#761  |  -6.728143   10.40984    -0.65   0.519    -27.31288    13.85659
  Treatment#762  |  -7.008939   12.43059    -0.56   0.574    -31.58957     17.5717
  Treatment#763  |   .2824135   9.887561     0.03   0.977    -19.26956    19.83439
  Treatment#764  |   2.491799   10.29973     0.24   0.809     -17.8752     22.8588
  Treatment#765  |   5.190039   13.68419     0.38   0.705     -21.8695    32.24958
  Treatment#766  |  -1.563607   16.84014    -0.09   0.926    -34.86383    31.73662
*/

* ~~~ Any ------------------------------------------------------------------
gen cont_tot = sayana + dmpa_im + pill + short_ + long_
areg cont_tot rand_group##date2, absorb(strata) cluster(health_cent_id) level(95)

matrix A = r(table)

matrix colnames A = a b c d e f g h i l m l n o p q r s t u v w z aa bb cc dd ee ff gg hh ii ll mm nn oo pp qq rr ss tt uu vv ww zz aaa bbb ccc ddd eee fff ggg hhh iii lll mmm nnn ooo ppp qqq rrr sss ttt uuu vvv www

// get original row names of matrix (and row count)
local rownames : rowfullnames A
local c : word count `rownames'

// get original column names of matrix and substitute out _cons
local names : colfullnames A
*local newnames : subinstr local names "_cons" "cons", word

// rename columns of matrix
*matrix colnames A = `newnames'

// convert to dataset
clear
svmat A

// add matrix row names to dataset
gen rownames = ""
forvalues i = 1/`c' {
    replace rownames = "`:word `i' of `rownames''" in `i'
}

keep A46 - A65 rownames

// check
order rownames
rename rownames _varname
xpose , clear varname
drop _varname
gen ym = _n+746
gen method_num = 1
gen method = "Any"

keep b se ll ul ym method_num method
rename ll ci95_lower 
rename ul ci95_upper

tempfile Any_95
save `Any_95'

/*
  Treatment#747  |  -29.36966   52.91227    -0.56   0.580         -134    75.26073
  Treatment#748  |   40.54339    66.9356     0.61   0.546    -91.81716    172.9039
  Treatment#749  |   -60.6885   51.95841    -1.17   0.245    -163.4327    42.05567
  Treatment#750  |   3.198827   76.45826     0.04   0.967    -147.9921    154.3898
  Treatment#751  |   8.021647   53.80864     0.15   0.882    -98.38124    114.4245
  Treatment#752  |   6.778786   48.35096     0.14   0.889    -88.83191    102.3895
  Treatment#753  |   145.7177    150.974     0.97   0.336     -152.823    444.2584
  Treatment#754  |   5.764092   54.07712     0.11   0.915    -101.1697    112.6979
  Treatment#755  |   7.798818   71.24596     0.11   0.913    -133.0852    148.6828
  Treatment#756  |  -94.98433   73.12423    -1.30   0.196    -239.5825     49.6138
  Treatment#757  |   86.44803   49.95982     1.73   0.086    -12.34408    185.2401
  Treatment#758  |  -91.91989   69.17657    -1.33   0.186    -228.7118    44.87201
  Treatment#759  |   57.39701   63.95211     0.90   0.371    -69.06389    183.8579
  Treatment#760  |  -35.81179   60.31826    -0.59   0.554     -155.087    83.46343
  Treatment#761  |   27.04482   65.88462     0.41   0.682    -103.2375    157.3271
  Treatment#762  |   40.09333   61.00231     0.66   0.512    -80.53453    160.7212
  Treatment#763  |  -31.77956   103.1042    -0.31   0.758    -235.6609    172.1018
  Treatment#764  |   137.9319   92.40111     1.49   0.138    -44.78494    320.6488
  Treatment#765  |  -23.69378   90.92725    -0.26   0.795    -203.4962    156.1086
  Treatment#766  |  -38.26013    101.677    -0.38   0.707    -239.3194    162.7991
*/

append using `sayana_95'
append using `condom_95'
append using `pill_95'
append using `dmpa_im_95'
append using `devices_95'


order method ym
sort method_num ym
drop method_num
rename b mg_effect

order method ym mg_effect se ci95_lower ci95_upper
format ym %tm



********************************************************************************
				* Event study of both outcomes together *
********************************************************************************
// All
twoway (scatter mg_effect ym if method=="Any", lcol(dkorange) mcol(black) msymbol(o)) (rcap ci95_upper ci95_lower ym if method=="Any", lcol(black)) (scatteri -250 747 400 747, c(l) m(i) lcol(black) lpat(dash_dot) lwidth(vthin)) (scatteri -250 753 400 753, c(l) m(i) lcol(black) lpat(dash_dot) lwidth(vthin)), yline(0, lpattern(dash) lcol(black)) graphregion(color(white)) xlabel(747 "Apr/2022" 748 "May/2022" 749 "Jun/2022" 750 "Jul/2022" 751 "Aug/2022" 752 "Nov/2022" 753 "Oct/2022" 754 "Nov/2022" 755 "Dec/2022" 756 "Jan/2023" 757 "Feb/2023" 758 "Mar/2023" 759 "Apr/2023" 760 "May/2023" 761 "Jun/2023" 762 "Jul/2023" 763 "Aug/2023" 764 "Sep/2023" 765 "Oct/2023" 766 "Nov/2023", angle(vertical) labsize(small))  xtitle("") ylabel(-250 0 400, angle(vertical)) legend(off) ytitle("{bf: Any}", size(medsmall)) yscale(titlegap(3)) ///
text(450 750 "{bf: CHW Training}" "", place(n) size(vsmall) col(black)) text(450 759 "{bf: Trained CHW}", place(n) size(vsmall) col(black)) xscale(off) name(g_any, replace) 

// g1: Sayana
twoway (scatter mg_effect ym if method=="Sayana", lcol(dkorange) mcol(black) msymbol(o)) (rcap ci95_upper ci95_lower ym if method=="Sayana", lcol(black)) (scatteri -10 747 60 747, c(l) m(i) lcol(black) lpat(dash_dot) lwidth(vthin)) (scatteri -10 753 60 753, c(l) m(i) lcol(black) lpat(dash_dot) lwidth(vthin)), yline(0, lpattern(dash) lcol(black)) graphregion(color(white)) xlabel(747 "Apr/2022" 748 "May/2022" 749 "Jun/2022" 750 "Jul/2022" 751 "Aug/2022" 752 "Nov/2022" 753 "Oct/2022" 754 "Nov/2022" 755 "Dec/2022" 756 "Jan/2023" 757 "Feb/2023" 758 "Mar/2023" 759 "Apr/2023" 760 "May/2023" 761 "Jun/2023" 762 "Jul/2023" 763 "Aug/2023" 764 "Sep/2023" 765 "Oct/2023" 766 "Nov/2023", angle(vertical) labsize(small))  xtitle("") ylabel(-20 0 60, angle(vertical)) legend(off) ytitle("{bf: Sayana Press}", size(medsmall)) yscale(titlegap(3)) xscale(off) name(g_say, replace) 

// g3: DMPA-IM
twoway (scatter mg_effect ym if method=="DMPA-IM", lcol(dkorange) mcol(black) msymbol(o)) (rcap ci95_upper ci95_lower ym if method=="DMPA-IM", lcol(black)) (scatteri -40 747 40 747, c(l) m(i) lcol(black) lpat(dash_dot) lwidth(vthin)) (scatteri -40 753 40 753, c(l) m(i) lcol(black) lpat(dash_dot) lwidth(vthin)), yline(0, lpattern(dash) lcol(black)) graphregion(color(white)) xlabel(747 "Apr/2022" 748 "May/2022" 749 "Jun/2022" 750 "Jul/2022" 751 "Aug/2022" 752 "Nov/2022" 753 "Oct/2022" 754 "Nov/2022" 755 "Dec/2022" 756 "Jan/2023" 757 "Feb/2023" 758 "Mar/2023" 759 "Apr/2023" 760 "May/2023" 761 "Jun/2023" 762 "Jul/2023" 763 "Aug/2023" 764 "Sep/2023" 765 "Oct/2023" 766 "Nov/2023", angle(vertical) labsize(small))  xtitle("") ylabel(-40(40)40, angle(vertical)) legend(off) ytitle("{bf: DMPA-IM}", size(medsmall)) yscale(titlegap(3)) name(g_dmpa, replace) xscale(off) text(45 750 "{bf: CHW Training}" "", place(n) size(vsmall) col(black)) text(45 759 "{bf: Trained CHW}", place(n) size(vsmall) col(black)) 

// g4: implants/IUD
twoway (scatter mg_effect ym if method=="Devices", lcol(dkorange) mcol(black) msymbol(o)) (rcap ci95_upper ci95_lower ym if method=="Devices", lcol(black)) (scatteri -10 747 5 747, c(l) m(i) lcol(black) lpat(dash_dot) lwidth(vthin)) (scatteri -10 753 5 753, c(l) m(i) lcol(black) lpat(dash_dot) lwidth(vthin)), yline(0, lpattern(dash) lcol(black)) graphregion(color(white)) xlabel(747 "Apr/2022" 748 "May/2022" 749 "Jun/2022" 750 "Jul/2022" 751 "Aug/2022" 752 "Nov/2022" 753 "Oct/2022" 754 "Nov/2022" 755 "Dec/2022" 756 "Jan/2023" 757 "Feb/2023" 758 "Mar/2023" 759 "Apr/2023" 760 "May/2023" 761 "Jun/2023" 762 "Jul/2023" 763 "Aug/2023" 764 "Sep/2023" 765 "Oct/2023" 766 "Nov/2023", angle(vertical) labsize(small))  xtitle("") ylabel(-10 0 5, angle(vertical)) legend(off) ytitle("{bf: Implants/IUD}", size(medsmall)) yscale(titlegap(3)) ///
name(g_long, replace) // xscale(off) text(10 750 "{bf: CHW Training}" "", place(n) size(vsmall) col(black)) text(10 759 "{bf: Trained CHW}", place(n) size(vsmall) col(black)) 

// g5: pill
twoway (scatter mg_effect ym if method=="Pill", lcol(dkorange) mcol(black) msymbol(o)) (rcap ci95_upper ci95_lower ym if method=="Pill", lcol(black)) (scatteri -250 747 150 747, c(l) m(i) lcol(black) lpat(dash_dot) lwidth(vthin)) (scatteri -250 753 150 753, c(l) m(i) lcol(black) lpat(dash_dot) lwidth(vthin)), yline(0, lpattern(dash) lcol(black)) graphregion(color(white)) xlabel(747 "Apr/2022" 748 "May/2022" 749 "Jun/2022" 750 "Jul/2022" 751 "Aug/2022" 752 "Nov/2022" 753 "Oct/2022" 754 "Nov/2022" 755 "Dec/2022" 756 "Jan/2023" 757 "Feb/2023" 758 "Mar/2023" 759 "Apr/2023" 760 "May/2023" 761 "Jun/2023" 762 "Jul/2023" 763 "Aug/2023" 764 "Sep/2023" 765 "Oct/2023" 766 "Nov/2023", angle(vertical) labsize(small))  xtitle("") ylabel(-250 0 150, angle(vertical)) legend(off) ytitle("{bf: Pills}", size(medsmall)) yscale(titlegap(3)) name(g_pill, replace) xscale(off) 

// g6: Condom + morning pill
twoway (scatter mg_effect ym if method=="Condom", lcol(dkorange) mcol(black) msymbol(o)) (rcap ci95_upper ci95_lower ym if method=="Condom", lcol(black)) (scatteri -250 747 450 747, c(l) m(i) lcol(black) lpat(dash_dot) lwidth(vthin)) (scatteri -250 753 450 753, c(l) m(i) lcol(black) lpat(dash_dot) lwidth(vthin)), yline(0, lpattern(dash) lcol(black)) graphregion(color(white)) xlabel(747 "Apr/2022" 748 "May/2022" 749 "Jun/2022" 750 "Jul/2022" 751 "Aug/2022" 752 "Nov/2022" 753 "Oct/2022" 754 "Nov/2022" 755 "Dec/2022" 756 "Jan/2023" 757 "Feb/2023" 758 "Mar/2023" 759 "Apr/2023" 760 "May/2023" 761 "Jun/2023" 762 "Jul/2023" 763 "Aug/2023" 764 "Sep/2023" 765 "Oct/2023" 766 "Nov/2023", angle(vertical) labsize(small))  xtitle("") ylabel(-250 0 450, angle(vertical)) legend(off) ytitle("{bf: Condoms}", size(medsmall)) yscale(titlegap(3)) name(g_condom, replace)

graph combine g_any g_say g_long g_dmpa g_pill g_condom, graphregion(color(white)) cols(2) colfirst



graph export "${appendix}/Figures/Figure A1.png", replace







