use "${final}/qt_contraceptives.dta", clear
merge m:1 health_cent_id using "${raw}/study sample/hc_treatment_status", keepusing(strata) nogen
merge m:1 health_cent_id using "${cleaned}/covariates", keepusing(d_rural dist_commune nTPS nASC nASC2 popfem PopfemPerASC) nogen

drop if date == ym(2023,12) // control group was treated from Dec/2023
display (138)*(12*3+11) // 6486 obs -> monthly obs for all 138 between Jan/2020-Dec/2023
count if sayana!=. // 6139 obs (95%) with non-missing obs on contraceptive methods

gen period = (date >= ym(2022,4)) // post-intervention indicator (since start of training)
gen x = rand_group*period


label def period_l 0 "Pre" 1 "Post"
label val period period_l

areg sayana rand_group##period, cluster(health_cent_id) absorb(strata)
keep if e(sample)==1

gen period_3 = 0 if inrange(date,ym(2020,1),ym(2022,3)) 
replace period_3 = 1 if inrange(date,ym(2022,4),ym(2022,9)) // From April to September 2022
replace period_3 = 2 if date==ym(2022,10) // October 2022
replace period_3 = 3 if date>ym(2022,10) // After October 2022

/*
cap erase "${tables}\Table3.xls"
cap erase "${tables}\Table3.txt"
*/
areg sayana rand_group##period_3, cluster(health_cent_id) absorb(strata)
keep if e(sample)==1
/*
local vars 1.rand_group#1.period_3 1.rand_group#2.period_3 1.rand_group#3.period_3 1.period_3 2.period_3 3.period_3 1.rand_group

foreach outcome in sayana_hc sayana_tps sayana_asc {
	areg `outcome' rand_group##period_3, cluster(health_cent_id) absorb(strata)
	su `outcome' if e(sample)==1 & period_3==0 
	outreg2 using "${tables}\Table3.xls", nocons dec(2) keep(`vars') sortvar(`vars') addstat(Mean Y, `r(mean)') adec(2)
}
*/

label def period_3l 0 "Pre" 1 "Theory" 2 "Practice"  3 "Eligibility"
label val period_3 period_3l
fre period_3

eststo clear
local vars vars 1.rand_group#1.period_3 1.rand_group#2.period_3 1.rand_group#3.period_3 1.period_3 2.period_3 3.period_3 1.rand_group
foreach outcome2 in sayana_hc sayana_tps sayana_asc {
eststo `outcome2': areg `outcome2' rand_group##period_3, cluster(health_cent_id) absorb(strata)
qui su `outcome2' if e(sample)==1 & period_3==0 
estadd scalar Mean= r(mean)
estadd scalar Within_R2= e(r2_w)
}
esttab sayana_hc sayana_tps sayana_asc using "${appendix}/Tables/TableB1.csv",  noconstant keep(`vars') order(`vars') b(2) se r2 label star(* 0.10 ** 0.05 *** 0.01) mtitles("Health Center" "Home Visit by HPO" "Home Visit by CHW") stats(N Mean, fmt(%9.0g %9.2f) labels("Observations" "Baseline mean")) replace