
********************************************************************************
							*** Table A1 Referrals ***
********************************************************************************

use "${final}/nfemcov_by_asc", clear
merge m:1 health_cent_id using "${raw}/study sample/hc_treatment_status", keepusing(strata) nogen
merge 1:1 date health_cent_id using "${final}/qt_contraceptives.dta", nogenerate

drop if date == ym(2023,12) // control group was treated from Dec/2023

gen period = (date >= ym(2022,4))

gen period_3 = 0 if inrange(date,ym(2020,1),ym(2022,3)) 
replace period_3 = 1 if inrange(date,ym(2022,4),ym(2022,9)) // From April to September 2022
replace period_3 = 2 if date==ym(2022,10) // October 2022
replace period_3 = 3 if date>ym(2022,10) // After October 2022

gen ncovfem_asc = ncovfem_new_asc + ncovfem_old_asc
gen nreferal_asc = new_referal_asc + old_referal_asc

reg sayana rand_group##period, cluster(health_cent_id)
keep if e(sample)==1
/*
cap erase "${tables}\TableA1.xls"
cap erase "${tables}\TableA1.txt"

local vars 1.rand_group#1.period 1.rand_group#1.period_3 1.rand_group#2.period_3 1.rand_group#3.period_3 1.period 1.period_3 2.period_3 3.period_3 1.rand_group

foreach outcome in nreferal_asc { // new_referal_asc ncovfem_asc ncovfem_new_asc 
	areg `outcome' rand_group##period, cluster(health_cent_id) absorb(strata)
	su `outcome' if e(sample)==1 & period==0 
	outreg2 using "${tables}\TableA1.xls", nocons dec(2) keep(`vars') sortvar(`vars') addstat(Mean Y, `r(mean)') adec(2)
	areg `outcome' rand_group##period_3, cluster(health_cent_id) absorb(strata)
	su `outcome' if e(sample)==1 & period==0 
	outreg2 using "${tables}\TableA1.xls", nocons dec(2) keep(`vars') sortvar(`vars') addstat(Mean Y, `r(mean)') adec(2)
}
*/
label def period_3l 0 "Pre" 1 "Theory" 2 "Practice"  3 "Eligibility"
label val period_3 period_3l
fre period_3

label def period_l 0 "Pre" 1 "Post"
label val period period_l

eststo clear
local vars 1.rand_group#1.period 1.rand_group#1.period_3 1.rand_group#2.period_3 1.rand_group#3.period_3 1.period 1.period_3 2.period_3 3.period_3 1.rand_group

eststo m1: areg nreferal_asc rand_group##period, cluster(health_cent_id) absorb(strata)
qui su nreferal_asc if e(sample)==1 & period==0 
estadd scalar Mean= r(mean)
estadd scalar Within_R2= e(r2_w)
eststo m2: areg nreferal_asc rand_group##period_3, cluster(health_cent_id) absorb(strata)
	su nreferal_asc if e(sample)==1 & period==0
	estadd scalar Mean= r(mean)
estadd scalar Within_R2= e(r2_w)

esttab m1 m2  using "${appendix}/Tables/TableB2.csv",  noconstant keep(`vars') order(`vars') b(2) se r2 label star(* 0.10 ** 0.05 *** 0.01) nodepvars  mgroups("CHW Referrals To Healt Centers") stats(N Mean, fmt(%9.0g %9.2f) labels("Observations" "Baseline mean")) replace