/*******************************************************************************
This do-file cleans outcome variables (data on contraceptives and referrals) at health center - month level
********************************************************************************/
		
* ---------------------------------------------------------------------------- *
* ---------------------------------------------------------------------------- *
* 		          CLEAN DATA FROM JAN/2020 UNTIL NOV/2023                      *
* ---------------------------------------------------------------------------- *
* ---------------------------------------------------------------------------- *

/*******************************************************************************
* 			1:  Cleans data at the health center - month level for the period 
				between Jan/2020 and Nov/2023. 
********************************************************************************
	REQUIRES:  	"${raw}/DONNEES PF-DSNIS-BM.xls"
				
	
	CREATES:	"${cleaned}/qt_in_hc_and_by_tps.dta": quantity of contraceptives 	  administered at the health center and by TPS
				"${cleaned}/nfemcov_new_by_method.dta": quantity of women taking each contraceptive method for the first-time"
				"${cleaned}/qt_by_asc.dta": quantity of contraceptives administered by CHW"
				
				WRITEN BY:  Paula Spinola & Michele Andreottola
*******************************************************************************/

*------------------------------------------------------------------------------ *
*------------------------------------------------------------------------------ *
				*** Quantity administered in Health Centers ***
*------------------------------------------------------------------------------ *
*------------------------------------------------------------------------------ *

clear

import excel "${raw}/DONNEES PF-DSNIS-BM.xls", firstrow case(lower) sheet("Tb2-PRODUITS ADMINISTRES") 

rename ds district
rename ar area_rural
rename cds health_cent
drop pays 


* ~~~ Turning periods as rows
su janvier2020-décembre2023 // no zeros

foreach v of varlist janvier2020-décembre2023 {
    destring `v', replace
    replace `v' = 0 if `v'==. // turning missings into zeros as reshape does not allow missings (we will come back to this)
    rename `v' qt`v'
}

reshape long qt, i(province district commune area_rural health_cent donnees) j(period) string


* ~~~ Turning name of contraceptive methods as column (i.e., variables)
replace donnees = "sayana_hc" if donnees=="Qte consommee Sayana Press (DMPA S/C)"
replace donnees = "dmpa_im_hc" if donnees==" Quantité administrée - DMPA"
replace donnees = "diu_hc" if donnees==" Quantité administrée - DIU"
replace donnees = "impl_hc" if donnees==" Quantité administrée - Implants"
replace donnees = "coc_hc" if donnees==" Quantité administrée - COC (oraux combinés)"
replace donnees = "cop_hc" if donnees==" Quantité administrée - COP (oraux à progestérone seul)"
replace donnees = "pres_m_hc" if donnees==" Quantité administrée - Préservatif masculin"
replace donnees = "pres_f_hc" if donnees==" Quantité administrée - Préservatif féminin"
replace donnees = "postinor_hc" if donnees==" Quantité administrée - POSTINOR"

reshape wide qt, i(province district commune area_rural health_cent period) j(donnees) string

foreach v in coc_hc cop_hc diu_hc impl_hc dmpa_im_hc postinor_hc pres_f_hc pres_m_hc sayana_hc {
    rename qt`v' `v'
	replace `v' = 0 if `v'==. // methods for each health centers reported no info although they submitted info
}

label var coc_hc "Quant Administered in Health Center - COC Pill"
label var cop_hc "Quant Administered in Health Center - COP Pill"
label var diu_hc "Quant Administered in Health Center - DIU"
label var dmpa_im_hc "Quant Administered in Health Center - DMPA-IM"
label var impl_hc "Quant Administered in Health Center - Implant"
label var postinor_hc "Quant Administered in Health Center - Emergency pill"
label var pres_f_hc "Quant Administered in Health Center - Female condom"
label var pres_m_hc "Quant Administered in Health Center - Male Condom"
label var sayana_hc "Quant Administered in Health Center - DMPA-SC (Sayana)"

* Cleaning period
gen year = real(substr(period,-4,4))
gen month_str = period
replace month_str = substr(month_str,1,length(month_str)-4)

gen month = 1 if month_str=="janvier"
replace month = 2 if month_str=="février"
replace month = 3 if month_str=="mars"
replace month = 4 if month_str=="avril"
replace month = 5 if month_str=="mai"
replace month = 6 if month_str=="juin"
replace month = 7 if month_str=="juillet"
replace month = 8 if month_str=="août"
replace month = 9 if month_str=="septembre"
replace month = 10 if month_str=="octobre"
replace month = 11 if month_str=="novembre"
replace month = 12 if month_str=="décembre"
label define mon 1 "Janvier" 2 "Février" 3 "Mars" 4  "Avril" 5 "Mai" 6 "Juin" 7 "Juillet" 8 "Août" 9 "Septembre" 10 "Octobre" 11 "Novembre" 12 "Décembre"
label values month mon
drop month_str

* Same manual fixes as above
replace health_cent="CDS Gashigwe" if province=="Cankuzo" & district=="DS Cankuzo" & commune=="Cendajuru" & area_rural=="AR Gashigwe" & health_cent=="CDS Gashirwe"
replace health_cent="CDS Runyankenzi" if province=="Kirundo" & district=="DS Vumbi" & commune=="Ntega" & area_rural=="AR Runyankezi" & health_cent=="CDS Runyankezi"
replace health_cent="CDS Bonero" if province=="Muyinga" & district=="DS Gashoho" & commune=="Gashoho" & area_rural=="AR Bonero" & health_cent=="CDS Bonero II"
replace health_cent="CDS Bonero" if province=="Muyinga" & district=="DS Muyinga" & commune=="Mwakiro" & area_rural=="AR Bonero" & health_cent=="CDS Bonero I"

save "${cleaned}/qt_in_hc_0", replace


*------------------------------------------------------------------------------ *
*------------------------------------------------------------------------------ *
		*** Additional variables (mostly at Health Center level) ***
*------------------------------------------------------------------------------ *
*------------------------------------------------------------------------------ *

clear
import excel "${raw}/DONNEES PF-DSNIS-BM.xls", firstrow case(lower) sheet("Tb3-PF ANCIENS ET NOUVEAUX") 

rename ds district
rename ar area_rural
rename cds health_cent
drop pays


* ~~~ Turning periods as rows
su janvier2020-décembre2023 // no zeros

foreach v of varlist janvier2020-décembre2023 {
    destring `v', replace
    replace `v' = 0 if `v'==. // turning missings into zeros as reshape does not allow missings (we will come back to this)
    rename `v' qt`v'
}

reshape long qt, i(province district commune area_rural health_cent methodes) j(period) string

* ~~~ Turning name of contraceptive methods as column (i.e., variables)
replace methodes = "dmpa_im_tps" if methodes=="PF : Quantité DMPA IM administrée par TPS"
replace methodes = "sayana_tps" if methodes=="PF : Quantité Sayana Press administrée par TPS"
replace methodes = "impl_ret" if methodes==" Nb d'implants retirés"
replace methodes = "diu_ret" if methodes==" Nb de DIU retirés"
replace methodes = "postinor2_hc" if methodes==" PF_Contraceptifs d'urgence administrés"
replace methodes = "ncovfem_stop" if methodes==" PF : Arret Methodes"
replace methodes = "ncovfem_eff" if methodes==" PF : Effets secondaires"
replace methodes = "nfem_part" if methodes==" PF : Nbre de femmes accompagnees par partenaire"
replace methodes = "ncovfem_old" if methodes==" PF : Anciens acceptants "
replace methodes = "ncovfem_old_age" if methodes==" PF : Anciens acceptants par Age"
replace methodes = "ncovfem_new_age" if methodes==" PF : Nouveaux acceptants par Age"
replace methodes = "ncovfem_new_ori" if methodes=="PF : Nouveaux acceptants par origine"
/*
- PF: Arrêt Méthodes: C'est une femme qui vient à la formation sanitaire pour demander d'arrêter la méthode sans demander une autre méthode.
- PF: Effets secondaires: ce sont les femmes qui vient en PF pour raison d'effet secondaire
*/

*replace methodes=strtrim(methodes)
reshape wide qt, i(province district commune area_rural health_cent period) j(methodes) string

foreach v in diu_ret dmpa_im_tps impl_ret ncovfem_eff ncovfem_new_age ncovfem_new_ori ncovfem_old ncovfem_old_age ncovfem_stop nfem_part postinor2_hc sayana_tps {
    rename qt`v' `v'
	replace `v' = 0 if `v'==. // methods for each health centers reported no info although they submitted info
}

label var dmpa_im_tps "Quant Administered by TPS - DMPA-IM"
label var sayana_tps "Quant Administered by TPS - DMPA-SC (Sayana)"
label var impl_ret "Quant Removed - Implant"
label var diu_ret "Quant Removed - DIU"
label var postinor2_hc "Quant Administered in Health Center - Emergency pill 2"
label var ncovfem_stop "Number of women stopping contraceptive"
label var ncovfem_eff "Number of women reporting contraceptive side effects"
label var nfem_part "Number of women visiting center with partner"
label var ncovfem_old "Number of women on contraceptives - since before"
label var ncovfem_old_age "Number of women on contraceptives, by age - since before"
label var ncovfem_new_age "Number of women on contraceptives, by age - new starters"
label var ncovfem_new_ori "Number of women on contraceptives, by origin - new starters"
label var province "Province"
label var district "District"
label var commune "Commune"
label var area_rural "Rural Area"
label var health_cent "Health Centre"

order province district commune area_rural health_cent period postinor2_hc sayana_tps dmpa_im_tps impl_ret diu_ret

* Cleaning period
gen year = real(substr(period,-4,4))
gen month_str = period
replace month_str = substr(month_str,1,length(month_str)-4)

gen month = 1 if month_str=="janvier"
replace month = 2 if month_str=="février"
replace month = 3 if month_str=="mars"
replace month = 4 if month_str=="avril"
replace month = 5 if month_str=="mai"
replace month = 6 if month_str=="juin"
replace month = 7 if month_str=="juillet"
replace month = 8 if month_str=="août"
replace month = 9 if month_str=="septembre"
replace month = 10 if month_str=="octobre"
replace month = 11 if month_str=="novembre"
replace month = 12 if month_str=="décembre"
label define mon 1 "Janvier" 2 "Février" 3 "Mars" 4  "Avril" 5 "Mai" 6 "Juin" 7 "Juillet" 8 "Août" 9 "Septembre" 10 "Octobre" 11 "Novembre" 12 "Décembre"
label values month mon
drop month_str

* Same manual fixes as above
replace health_cent="CDS Gashigwe" if province=="Cankuzo" & district=="DS Cankuzo" & commune=="Cendajuru" & area_rural=="AR Gashigwe" & health_cent=="CDS Gashirwe"
replace health_cent="CDS Runyankenzi" if province=="Kirundo" & district=="DS Vumbi" & commune=="Ntega" & area_rural=="AR Runyankezi" & health_cent=="CDS Runyankezi"
replace health_cent="CDS Bonero" if province=="Muyinga" & district=="DS Gashoho" & commune=="Gashoho" & area_rural=="AR Bonero" & health_cent=="CDS Bonero II"
replace health_cent="CDS Bonero" if province=="Muyinga" & district=="DS Muyinga" & commune=="Mwakiro" & area_rural=="AR Bonero" & health_cent=="CDS Bonero I"

save "${cleaned}/qt_by_tps_and_nfemcov_0", replace


*------------------------------------------------------------------------------ *
*------------------------------------------------------------------------------ *
		*** N women taking up contraceptives for the first time ***
*------------------------------------------------------------------------------ *
*------------------------------------------------------------------------------ *
* Q: Do these only concern health centers?

clear
import excel "${raw}/DONNEES PF-DSNIS-BM.xls", firstrow case(lower) sheet("Tb1-NOUVELLES ACCEPTENTES") 

rename donnees methodes
rename ds district
rename ar area_rural
rename cds health_cent
drop pays precisiondeformulaire

* ~~~ Turning periods as rows
su janvier2020-décembre2023 // no zeros

foreach v of varlist janvier2020-décembre2023 {
    destring `v', replace
    replace `v' = 0 if `v'==. // turning missings into zeros as reshape does not allow missings (we will come back to this)
    rename `v' qt`v'
}

reshape long qt, i(province district commune area_rural health_cent methodes) j(period) string

* ~~~ Turning name of contraceptive methods as column (i.e., variables)
replace methodes = "newfem_sayana" if methodes=="Sayana Press"
replace methodes = "newfem_dmpa_im" if methodes=="DMPA IM"
replace methodes = "newfem_diu" if methodes=="DIU"
replace methodes = "newfem_impl" if methodes=="Implant"
replace methodes = "newfem_coc" if methodes=="COC"
replace methodes = "newfem_cop" if methodes=="COP"
replace methodes = "newfem_pres_m" if methodes=="Préservatifs masculins"
replace methodes = "newfem_pres_f" if methodes=="Préservatifs féminins"

reshape wide qt, i(province district commune area_rural health_cent period) j(methodes) string

foreach v in newfem_coc newfem_cop newfem_diu newfem_dmpa_im newfem_impl newfem_pres_f newfem_pres_m newfem_sayana {
    rename qt`v' `v'
	replace `v' = 0 if `v'==. // methods for each health centers reported no info although they submitted info
}

label var newfem_coc "Number of NEW adopters of COC Pill"
label var newfem_cop "Number of NEW adopters of COP Pill"
label var newfem_diu "Number of NEW adopters of DIU"
label var newfem_dmpa_im "Number of NEW adopters of DMPA-IM"
label var newfem_impl "Number of NEW adopters of Implant"
label var newfem_pres_f "Number of NEW adopters of Female condom"
label var newfem_pres_m "Number of NEW adopters of Male Condom"
label var newfem_sayana "Number of NEW adopters of DMPA-SC (Sayana)"
label var province "Province"
label var district "District"
label var commune "Commune"
label var area_rural "Rural Area"
label var health_cent "Health Centre"

* Cleaning period
gen year = real(substr(period,-4,4))
replace period = substr(period,1,length(period)-4)
gen month = 1 if period=="janvier"
replace month = 2 if period=="février"
replace month = 3 if period=="mars"
replace month = 4 if period=="avril"
replace month = 5 if period=="mai"
replace month = 6 if period=="juin"
replace month = 7 if period=="juillet"
replace month = 8 if period=="août"
replace month = 9 if period=="septembre"
replace month = 10 if period=="octobre"
replace month = 11 if period=="novembre"
replace month = 12 if period=="décembre"
label define mon 1 "Janvier" 2 "Février" 3 "Mars" 4  "Avril" 5 "Mai" 6 "Juin" 7 "Juillet" 8 "Août" 9 "Septembre" 10 "Octobre" 11 "Novembre" 12 "Décembre"
label values month mon
drop period

* Same manual fixes as above
replace health_cent="CDS Gashigwe" if province=="Cankuzo" & district=="DS Cankuzo" & commune=="Cendajuru" & area_rural=="AR Gashigwe" & health_cent=="CDS Gashirwe"
replace health_cent="CDS Runyankenzi" if province=="Kirundo" & district=="DS Vumbi" & commune=="Ntega" & area_rural=="AR Runyankezi" & health_cent=="CDS Runyankezi"
replace health_cent="CDS Bonero" if province=="Muyinga" & district=="DS Gashoho" & commune=="Gashoho" & area_rural=="AR Bonero" & health_cent=="CDS Bonero II"
replace health_cent="CDS Bonero" if province=="Muyinga" & district=="DS Muyinga" & commune=="Mwakiro" & area_rural=="AR Bonero" & health_cent=="CDS Bonero I"

save "${cleaned}/nfemcov_new_by_method_0", replace


*------------------------------------------------------------------------------ *
*------------------------------------------------------------------------------ *
		*** Qt of contraceptives distributed/administered by CHW ***
*------------------------------------------------------------------------------ *
*------------------------------------------------------------------------------ *
// We don't have info on CDS, but we do have info on urban area, which for our sample identifies health centers

clear
import excel "${raw}/DONNEES PF-DSNIS-BM.xls", firstrow case(lower) sheet("Tb4-GASC -CONTRACEPTIFS") 

rename ds district
rename ar area_rural
drop pays

* ~~~ Turning periods as rows
su janvier2020-décembre2023 // no zeros

foreach v of varlist janvier2020-décembre2023 {
    destring `v', replace
    replace `v' = 0 if `v'==. // turning missings into zeros as reshape does not allow missings (we will come back to this)
    rename `v' qt`v'
}

reshape long qt, i(province district commune area_rural gascpf) j(period) string

* ~~~ Turning name of contraceptive methods as column (i.e., variables)
replace gascpf = "sayana_asc" if gascpf=="GASC : DBC Quantité distribuée Sayana Press"
replace gascpf = "pill_asc" if gascpf==" GASC_DBC Pilules Quantite distribuée aucours du mois"
replace gascpf = "pres_f_asc" if gascpf==" GASC_DBC Preservatifs Féminin PF Quantité distribuée aucours du mois"
replace gascpf = "pres_m_asc" if gascpf==" GASC_DBC Preservatifs Masculin PF Quantité distribuée aucours du mois"

replace gascpf = "ncovfem_new_asc" if gascpf==" GASC_PF  accompagnés par ASC"
replace gascpf = "ncovfem_old_asc" if gascpf==" GASC_Sous PF_Accompagnés par ASC"

replace gascpf = "new_referal_asc" if gascpf==" GASC_PF référés"
replace gascpf = "old_referal_asc" if gascpf==" GASC_PF contre- référés"

replace gascpf = "nfem_rec_mod_asc" if gascpf=="FBP_GASC : Cas de récupération d’abandon d’une méthode contraceptive moderne"
replace gascpf = "nfem_rec_asc" if gascpf==" GASC_Sous PF_Nb récupérés"
replace gascpf = "nfem_aban_asc" if gascpf==" GASC_Sous PF_Perdu de vue ou abandon"

/*
- GASC-PF référés : ce sont des cas d'adhésion à la PF référés par les ASC ces cas arrivent à la FOSA avec un billet de transfert des ASC 
- GASC -PF contre référés: ce sont cas que la FOSA sanitaire contre-réfère au ASC pour continuer les méthodes de PF qui sont déjà données par les ASC dans la communauté.

- GASC_PF accompagnés par ASC: ce sont les femmes nouvelles acceptantes qui ont été accompagnées par les ASC
- GASC_sous PF accompagnés par ASC: ce sont les femmes anciennes acceptantes qui ont été accompagnées par les ASC

- GASC_Sous PF Perdu de vue ou abandon: les femmes qui ont passé plus de 6 mois sans revenir renouveler leur méthode
- GASC_Sous PF_Nb récupérés: les femmes qui ont abandonné depuis 6 mois les méthodes contraceptives mais qui sont ramenées par les ASC
*/

reshape wide qt, i(province district commune area_rural period) j(gascpf) string

foreach v in ncovfem_new_asc ncovfem_old_asc new_referal_asc nfem_aban_asc nfem_rec_asc nfem_rec_mod_asc old_referal_asc pill_asc pres_f_asc pres_m_asc sayana_asc {
    rename qt`v' `v'
	replace `v' = 0 if `v'==. // methods for each health centers reported no info although they submitted info
}

label var pill_asc "Quant Administered by CHW - Pill"
label var pres_f_asc "Quant Administered by CHW - Female condom"
label var pres_m_asc "Quant Administered by CHW - Male Condom"
label var sayana_asc "Quant Administered by CHW - DMPA-SC (Sayana)"

label var ncovfem_new_asc "N. NEW contraceptive users seen by CHW"
label var ncovfem_old_asc "N. OLD contraceptive users seen by CHW"
label var new_referal_asc "N. women referred by CHW to health centers for new adoption"
label var old_referal_asc "N. women referred by CHW to health centers for continuation"

label var nfem_aban_asc "N. women having discontinued adoption (> 6 months without renewal)"
label var nfem_rec_asc "N. women who discontinued adoption re-engaged by CHW"
label var nfem_rec_mod_asc "N. women who discontinued modern contraceptive adoption re-engaged by CHW"

label var province "Province"
label var district "District"
label var commune "Commune"
label var area_rural "Rural Area"
*label var health_cent "Health Centre"

* Cleaning period
gen year = real(substr(period,-4,4))
replace period = substr(period,1,length(period)-4)
gen month = 1 if period=="janvier"
replace month = 2 if period=="février"
replace month = 3 if period=="mars"
replace month = 4 if period=="avril"
replace month = 5 if period=="mai"
replace month = 6 if period=="juin"
replace month = 7 if period=="juillet"
replace month = 8 if period=="août"
replace month = 9 if period=="septembre"
replace month = 10 if period=="octobre"
replace month = 11 if period=="novembre"
replace month = 12 if period=="décembre"
label define mon 1 "Janvier" 2 "Février" 3 "Mars" 4  "Avril" 5 "Mai" 6 "Juin" 7 "Juillet" 8 "Août" 9 "Septembre" 10 "Octobre" 11 "Novembre" 12 "Décembre"
label values month mon
drop period

save "${cleaned}/qt_by_asc_0", replace


*------------------------------------------------------------------------------ *
*------------------------------------------------------------------------------ *
							*** Final dtas ***
*------------------------------------------------------------------------------ *
*------------------------------------------------------------------------------ *

* ~~~ File 1 qt_in_hc_and_by_tps.dta: Main file, variables on contraceptives distributed/administered at health centers of by TPS
use "${cleaned}/qt_in_hc_0", clear
merge 1:1 province district commune area_rural health_cent period using "${cleaned}/qt_by_tps_and_nfemcov_0", keep(match) nogenerate // we are only keeping those in both files because all of the 138 health centers in our final sample are reported in both files
drop period

* Trying to understand difference between 2 variables on contraceptive emmergency pill
gen check = (postinor_hc == postinor2_hc)
tab check
gen diff = postinor_hc - postinor2_hc
su diff
count if postinor_hc==0
count if postinor2_hc==0
drop postinor2_hc check diff // keep the variable from the first file (same one that had been previously sent)


*Here we merge with the sample dataset, which included all health centers where 
*Sayana Press was already available but CHWs had not yet been trained before the beginning of the intervention. These are 138.
merge m:1 province district commune area_rural health_cent using "${raw}/study sample/health_cent_id_sample", keepusing(health_cent_id)

/*
    Result                      Number of obs
    -----------------------------------------
    Not matched                        39,456
        from master                    39,456  (_merge==1)
        from using                          0  (_merge==2)

    Matched                             6,624  (_merge==3)
    -----------------------------------------
	
	6624 = (138)*(12*4) --> correct: 12 observation per year, per 4 years 
	per 138 health centers
*/
keep if _merge == 3 // we keep only the sample observations
drop _merge 

*DECISION: since we do not know if missing values are "zero" or if data have not been reported, we proceed as following:
*if no data on any contraceptive has been reported in a particular month, we assume that the monthly observation is missing.
*if, on the other hand, in a particular month, some variables have been reported and some are missing, we turn missing into zeros
* Turning into missing when zero is reported for all contraceptives
gen total_hc = coc_hc + cop_hc + diu_hc + dmpa_im_hc + impl_hc + postinor_hc + pres_f_hc + pres_m_hc + sayana_hc
foreach c in coc_hc cop_hc diu_hc dmpa_im_hc impl_hc postinor_hc pres_f_hc pres_m_hc sayana_hc {
	replace `c'=. if total_hc==0
}
drop total_hc
codebook health_cent_id if sayana_hc!=. // Check: all 138  have reported sayana press for at least 1 month


*add ym variable and variable on treatment assignment
gen date = ym(year, month)
format date %tm
merge m:1 health_cent_id using "${raw}/study sample/hc_treatment_status.dta", keepusing(rand_group) keep(match) nogenerate
order date year month rand_group health_cent_id

codebook health_cent_id // 138

display _N
display (138)*(12*4) // monthly obs for all 138 between Jan/2020-Dec/2023

save "${cleaned}/qt_in_hc_and_by_tps", replace


* ~~~ File 2 nfemcov_new_by_method.dta : Auxiliary file, on number of women adopting each contraceptive method

use "${cleaned}/nfemcov_new_by_method_0", clear


*Again, we merge with the sample dataset
merge m:1 province district commune area_rural health_cent using "${raw}/study sample/health_cent_id_sample", keepusing(health_cent_id)

/*

    Result                      Number of obs
    -----------------------------------------
    Not matched                        36,720
        from master                    36,720  (_merge==1)
        from using                          0  (_merge==2)

    Matched                             6,624  (_merge==3)
    -----------------------------------------

	6624 = (138)*(12*4) --> correct: 12 observation per year, per 4 years 
	per 138 health centers
*/
keep if _merge == 3 // we keep only the sample observations
drop _merge 

* add ym variable and variable on treatment assignment
gen date = ym(year, month)
format date %tm
merge m:1 health_cent_id using "${raw}/study sample/hc_treatment_status.dta", keepusing(rand_group) keep(match) nogenerate
order date rand_group

codebook health_cent_id // 138

display _N
display (138)*(12*4) // monthly obs for all 138 between Jan/2020-Dec/2023

save "${cleaned}/nfemcov_new_by_method", replace



* ~~~ File 3 qt_by_asc.dta : info on qt of contraceptive method distributed by CHW

use "${cleaned}/qt_by_asc_0", clear

*Again, we merge with the sample dataset
merge m:1 province district commune area_rural using "${raw}/study sample/health_cent_id_sample",keepusing(health_cent_id health_cent)

/*

    Result                      Number of obs
    -----------------------------------------
    Not matched                        29,904
        from master                    29,904  (_merge==1)
        from using                          0  (_merge==2)

    Matched                             6,624  (_merge==3)
    -----------------------------------------

	6624 = (138)*(12*4) --> correct: 12 observation per year, per 4 years 
	per 138 health centers
*/
keep if _merge == 3 // we keep only the sample observations
drop _merge 


* add ym variable and variable on treatment assignment
gen date = ym(year, month)
format date %tm
merge m:1 health_cent_id using "${raw}/study sample/hc_treatment_status.dta", keepusing(rand_group) nogenerate
order date rand_group health_cent_id province district commune area_rural health_cent pill_asc pres_f_asc pres_m_asc sayana_asc

codebook health_cent_id // 138

display _N
display (138)*(12*4) // monthly obs for all 138 between Jan/2020-Dec/2023

save "${cleaned}/qt_by_asc", replace

* ~~~ Erase unnecessary files
erase "${cleaned}/qt_in_hc_0.dta"
erase "${cleaned}/qt_by_tps_and_nfemcov_0.dta"
erase "${cleaned}/nfemcov_new_by_method_0.dta"
erase "${cleaned}/qt_by_asc_0.dta"





