/*******************************************************************************
This do-file generates a dataset to make summary stats and evaluate balance
********************************************************************************

********************************************************************************
	REQUIRES:  	"${raw}/Population\Population et nombre de femmes âgées de15 à 49 ans par CDS en 2023.xls"
				"${raw}/Providers/Liste_CDS avec TPS et ASC.xlsx"
				"${raw}/Providers/ASC non encore formés dans les centres de sante Burundi EI échantillonés.xls"
				"${raw}/rural_vs_urban/STATUT URBAIN OU RURAL DES 138 CDS ET KMs ESTIMES ENTRE LES ENTITES PAR RAPPORT AUX CDS.xls"
				${raw}/study sample/hc_treatment_status.dta
				
				
	
	CREATES:	"${cleaned}/covariates.dta"
	
	WRITEN BY:  Paula Spinola & Michele Andreottola
*******************************************************************************/


********************************************************************************
					*** Preparing dta with covariates ***
********************************************************************************
clear

// Population of childbearing age women ----------------------------------------
import excel "${raw}/Population/Population et nombre de femmes âgées de15 à 49 ans par CDS en 2023.xls", firstrow clear

gen check = (orgunitlevel5 == organisationunitname)
tab check
drop orgunitlevel5 check

gen health_cent = subinstr(organisationunitname,"AR", "CDS", .)

rename (orgunitlevel2 orgunitlevel3 orgunitlevel4) (province district commune)
rename (PopulationtotaleAR Nchildbearingagewomen) (pop popfem)

isid province district commune health_cent
drop orgunitlevel1 organisationunitname periodname


// Keep only info on 138 CDS in our study sample -------------------------------
* before, perform some manual fixes
replace health_cent="CDS Musenyi (de Cankuzo)" if health_cent=="CDS Musenyi" & commune=="Cankuzo"
replace health_cent="CDS Runyankenzi" if health_cent=="CDS Runyankezi"
merge 1:1 province district commune health_cent using "${raw}\study sample\health_cent_id_sample", keep(match) nogen


// Add number of ASC & TPS -----------------------------------------------------
preserve 
	import excel "${raw}/Providers/Liste_CDS avec TPS et ASC.xlsx", firstrow clear
	keep if _n<=138
	drop NdordredesCDS AirdeResponsabilité I J K
	rename (Province District Commune CentredeSanté NombredASCparCDS NombredeTPSparCDS) (province district commune health_cent nASC nTPS)
	replace nTPS = 0 if nTPS==. // 100 CDS have no TPS and 38 remaining have 1 TPS
	su nTPS nASC
	tempfile nASC_TPS
	save `nASC_TPS', replace
restore
merge 1:1 province district commune health_cent using `nASC_TPS', keep(match) nogen


// Add number of ASC -----------------------------------------------------------
preserve
	import excel "${raw}/Providers/ASC non encore formés dans les centres de sante Burundi EI échantillonés.xls", firstrow sheet("ASC dans les CDS de l'étude") clear
	keep if _n<=138
	keep province district commune health_cent NombredASC
	destring NombredASC, replace
	rename NombredASC nASC2
	tempfile nASC
	save `nASC', replace
restore
merge 1:1 province district commune health_cent using `nASC', keep(match) nogen


// Indicator Rural vs Urban ----------------------------------------------------
preserve
	import excel "${raw}/rural_vs_urban/STATUT URBAIN OU RURAL DES 138 CDS ET KMs ESTIMES ENTRE LES ENTITES PAR RAPPORT AUX CDS", firstrow sheet("Sheet1") case(lower) clear
	rename (centredesanté j k) (health_cent dist_district dist_commune)
	gen d_rural = 1 if inlist(statutducdsruralurbainnb,"Rural","rural")
	replace d_rural = 0 if inlist(statutducdsruralurbainnb,"Urbain","urbain")
	keep province district commune d_rural health_cent dist_district dist_commune
	lab var dist_district "Estimated distance (km) between CDS and the 'bureau du district sanitaire'"
	lab var dist_commune "Estimated distance (km) between CDS and the 'bureau de la commune'"
	tempfile distance
	save `distance', replace
restore
merge 1:1 province district commune health_cent using `distance', keep(match) nogen

/*
count if d_rural==. // no missing
count if dist_commune==. // no missing (zero if same building)
count if popfem==. // no missing
count if nASC==. // no missing
*/

order province district commune health_cent health_cent_id d_rural dist_district dist_commune nTPS nASC nASC2 pop popfem
gen PopfemPerASC = popfem/nASC
su d_rural dist_commune nTPS nASC nASC2 popfem PopfemPerASC

merge m:1 health_cent_id using "${raw}/study sample/hc_treatment_status.dta", keepusing(rand_group) nogenerate

save "${cleaned}/covariates.dta", replace




