/*******************************************************************************
This do-file creates new outcome variables and combines cleaned datasets to create final dataset for analysis
********************************************************************************/

/*******************************************************************************
	REQUIRES:  	"${cleaned}\qt_in_hc_and_by_tps"
				"${cleaned}\nfemcov_new_by_method"
				"${cleaned}\qt_by_asc"
				
	
	CREATES:	"${final}\qt_contraceptives"
				"${final}\nfemcov"
				"${final}\nfemcov_by_asc"
*******************************************************************************/

*------------------------------------------------------------------------------ *
*------------------------------------------------------------------------------ *
						*** Adding all together ***
*------------------------------------------------------------------------------ *
*------------------------------------------------------------------------------ *

* ~~~ Dta with sum of n of contraceptives administered by type -----------------
use "${cleaned}/qt_in_hc_and_by_tps", clear
keep date-province coc_hc-diu_ret

gen pill_hc = coc_hc + cop_hc
gen condom_hc = pres_f_hc + pres_m_hc
lab var pill_hc "Quant Administered in Health Center - Pill"
lab var condom_hc "Quant Administered in Health Center - Condom"
drop coc_hc cop_hc pres_f_hc pres_m_hc

merge 1:1 health_cent_id date using "${cleaned}\qt_by_asc.dta", keepusing(rand_group sayana_asc pill_asc pres_f_asc pres_m_asc) nogenerate
// the using dta has all obs (including Sept-Oct-Nov/2023 for the 7 health centers for which no info on qt administered in CDS)
gen condom_asc = pres_f_asc + pres_m_asc
lab var condom_asc "Quant Administered by CHW - Condom"
drop pres_f_asc pres_m_asc

su sayana_hc dmpa_im_hc pill_hc condom_hc // some missings for HC
su sayana_tps dmpa_im_tps // some missings for TPS
su sayana_asc pill_asc condom_asc // no missings for ASC

gen sayana = sayana_hc + sayana_tps + sayana_asc // adm by all three providers (HC, TPS, CHW)
replace sayana = sayana_hc + sayana_asc if sayana_tps==.

gen dmpa_im = dmpa_im_hc + dmpa_im_tps // distributed by HC and TPS
replace dmpa_im = dmpa_im_hc if dmpa_im_tps==.

gen pill = pill_hc + pill_asc // distributed by HC and CHW
gen condom = condom_hc + condom_asc // distributed by HC and CHW

* ~~~ Stock measure
bys health_cent_id: gen say_3m_hc = sayana_hc + sayana_hc[_n-1] + sayana_hc[_n-2]
bys health_cent_id: gen say_3m_tps = sayana_tps + sayana_tps[_n-1] + sayana_tps[_n-2]
bys health_cent_id: gen say_3m_asc = sayana_asc + sayana_asc[_n-1] + sayana_asc[_n-2]
gen say_3m = say_3m_hc + say_3m_tps + say_3m_asc
bys health_cent_id: replace say_3m = . if sayana==. | sayana[_n-1]==. | sayana[_n-2]==.
*replace say_3m = . if sayana_hc==.
*replace say_3m = . if sayana_tps==. // this variable doesnt seem very reliable, and when non-missing, it is very small
*replace say_3m = . if sayana_asc==. // control group does not have any quantity administered by ASC (not eligible)
drop say_3m_*

* ~~~ Net flow measure
bys health_cent_id: gen say_3m_net_hc = sayana_hc + sayana_hc[_n-1] + sayana_hc[_n-2] - sayana_hc[_n-3]
bys health_cent_id: gen say_3m_net_tps = sayana_tps + sayana_tps[_n-1] + sayana_tps[_n-2] - sayana_tps[_n-3]
bys health_cent_id: gen say_3m_net_asc = sayana_asc + sayana_asc[_n-1] + sayana_asc[_n-2] - sayana_asc[_n-3]
gen say_3m_net = say_3m_net_hc + say_3m_net_tps + say_3m_net_asc
bys health_cent_id: replace say_3m_net = . if sayana==. | sayana[_n-1]==. | sayana[_n-2]==. | sayana_asc[_n-3]==.
drop say_3m_net_*
su say_3m*

/*
* ~~~ Renewal measure
bys health_cent_id: gen say_flow = max(sayana - sayana[_n-3], 0)
replace say_flow = . if sayana==.
su say_flow
*/

save "${final}/qt_contraceptives", replace


* ~~~ Dta with info on number of women on contraceptive use --------------------
use "${cleaned}/qt_in_hc_and_by_tps", clear
keep date-province ncovfem_eff-nfem_part

merge 1:1 health_cent_id date using "${cleaned}/nfemcov_new_by_method", nogenerate
drop district commune area_rural health_cent year month

save "${final}/nfemcov", replace


* ~~~ Dta with info on CHW indicators --------------------
use "${cleaned}/qt_by_asc.dta", clear
keep date-province ncovfem_new_asc-old_referal_asc

save "${final}/nfemcov_by_asc", replace

