/*******************************************************************************
* 			"Community Health Workers As Key Providers of Easy-to-Use
						Contraceptive Injectables:
					Experimental Evidence from Rural Burundi"
*   					  	   MASTER DO-FILE							   	   *
********************************************************************************

					PART 0:  User inputs
					PART 1:  Prepare folder paths
					PART 2:  Load necessary packages
					PART 3:  Run selected code

********************************************************************************
	PART 0: USER INPUTS															
********************************************************************************/

//	Set user-dependant project paths -------------------------------------------

/* WELCOME!!! ARE YOU NEW TO THIS CODE?
   Add yourself by changing your directory below */
	global path ""
	
	sysdir set PLUS "${path}/Code/ado"
	ieboilstart, v(15.1)  matsize(10000)
	`r(version)'
	
// Select sections to run ------------------------------------------------------

	local  sample_definition 1 // Define sample
	local  randomization	1 // Re-randomizes sample
	local  packages			0 // Install user-written commands used in the project
	local  cleaning			1 // Re-clean datasets
	local  construction		1 // Re-create analysis indicators
	local  mainresults		1 // Re-create analysis outputs



/*******************************************************************************
					PART 1:  Prepare folder paths
*******************************************************************************/
** Folders globals
	global Mainfold		"${path}"
	global user_git		"${path}/Code"

	* Do files
	global dorand       "${user_git}/Preliminary"
	global doclean     	"${user_git}/Cleaning"
	global doconstr    	"${user_git}/Construct"
	global doanalysis    "${user_git}/Analysis"
	
	global doanpaper     "${doanalysis}/1_Paper"
	global doanapp       "${doanalysis}/2_Appendix"

	* Data sets
	global prelim       "${Mainfold}/Data/00_preliminary"
	global raw        	"${Mainfold}/Data/01_raw"
	global cleaned      "${Mainfold}/Data/02_cleaned"
	global final        "${Mainfold}/Data/03_final"
	
	* Outputs
	* Paper
	global paper        "${Mainfold}/Output/1_Paper"
	global appendix     "${Mainfold}/Output/2_Appendix"

/*******************************************************************************
					PART 2:  Load necessary packages
********************************************************************************
{

	* Install packages
	if `packages' {
		foreach package in ietoolkit iefieldkit randtreat outreg2 rwolf2 fre estout {
			capture which `package'
            if _rc == 111	ssc install `package'
		}
	}
} */

********************************************************************************
*					   PART 3: Run selected code     						   *
********************************************************************************
	
	if `sample_definition' 	    {
						do "${dorand}/00.sample_definition.do"
	}
	
	if `randomization' 	    {
						do "${dorand}/01.creating_var_for_rand.do"
						do "${dorand}/02.randomization_final.do"
	}

	if `cleaning' 	    {
						do "${doclean}/1A_CLEANS_CONTRACEPTIVE_DATA.do"
						do "${doclean}/2_COVARIATES_creates_dta.do"
	}
	
	if `construction' 	    do "${doconstr}/Construct.do"
	if `mainresults' 	do "${doanalysis}/MASTER_paper_results.do"
  
/*******************************************************************************
	Congratulations, you've made it to the end of the do files!
*******************************************************************************/

