/*******************************************************************************
In this do-file the final sample of health centers is defined
********************************************************************************/
		
* ---------------------------------------------------------------------------- *
* ---------------------------------------------------------------------------- *
* 		                      SAMPLE DEFINITION                                *
* ---------------------------------------------------------------------------- *
* ---------------------------------------------------------------------------- *

/*******************************************************************************
* 			1:  // Importing List of Health centers DHIS 2020
*         This was the version used to generate health facility IDs 
********************************************************************************
	REQUIRES:  	"${prelim}/DHIS_health_centers_2020.xlsx"
				"${prelim}/FOSA PUBLIQUES OFFRANT SAYANA PRESS.xls"	
	
	CREATES:	"${raw}/study sample/health_cent_id_sample.dta": final sample of health centers
				
				WRITEN BY:  Michele Andreottola
*******************************************************************************/



import excel "${prelim}/DHIS_health_centers_2020.xlsx", firstrow clear



/*******************************************************************************
 A) Cleaning names
********************************************************************************/

rename orgunitlevel1 country 
label var country "Country"
rename orgunitlevel2 province
label var province "Province"
rename orgunitlevel3 district
label var district "District"
rename orgunitlevel4 commune
label var commune "Commune"
rename orgunitlevel5 area_rural
label var area_rural "Rural Area"
rename orgunitlevel6 health_cent
label var health_cent "Health Centre"
drop country organisationunitname // irrelavent


/*******************************************************************************
 B) Generating and ID variable that uniquely identifies each health center (1252 health centers in total)
********************************************************************************/

sort province district commune health_cent
egen health_cent_id = group( province district commune health_cent )
tostring health_cent_id, replace
replace health_cent_id = "HC" + health_cent_id if strlen(health_cent_id)==4
replace health_cent_id = "HC0" + health_cent_id if strlen(health_cent_id)==3
replace health_cent_id = "HC00" + health_cent_id if strlen(health_cent_id)==2
replace health_cent_id = "HC000" + health_cent_id if strlen(health_cent_id)==1
tab health_cent_id // there should be 36 observation per each health center

label var health_cent_id "Health Centre ID"


/*******************************************************************************
 C) Selecting sample
 
	PREREQUISITE FOR SELECTION IN THE STUDY SAMPLE:  
	1) Only keep HC that belong to 6 provinces where project NKURIZA operates.
	2) Only keep HC where ASC have not yet been trained (as per excel shared by the government)
********************************************************************************/


codebook province // 18
codebook health_cent_id // 1252

*Only keep HC that belong to 6 provinces where project NKURIZA operates.
keep if inlist(province, "Bubanza", "Cankuzo", "Cibitoke", "Kirundo", "Makamba", "Muyinga") // 410 in the six selected provinces

preserve 

*import dataset received in Jan 2022 contaning list of health centers offering 
* Sayana Press within the 6 project regions
import excel "${prelim}/FOSA PUBLIQUES OFFRANT SAYANA PRESS.xls", sheet("2021") firstrow clear
tab ASC_trained

tempfile hc_offering_sayana
save `hc_offering_sayana'

restore

merge m:1 province district commune health_cent using `hc_offering_sayana', keepusing(province district commune ASC_trained)
keep if _merge == 3 // keep only health centers offering Sayana
drop _merge

codebook province // 6
codebook health_cent_id // 202

keep if ASC_trained!="yes" // where ASC had not yet been trained
drop ASC_trained

codebook province // 6
codebook health_cent_id // 138

codebook health_cent_id if province=="Bubanza" // 15
codebook health_cent_id if province=="Cankuzo" // 20
codebook health_cent_id if province=="Cibitoke" // 36
codebook health_cent_id if province=="Kirundo" // 26
codebook health_cent_id if province=="Makamba" // 5
codebook health_cent_id if province=="Muyinga" // 36

order health_cent_id, before(province)

save "${raw}/study sample/health_cent_id_sample.dta", replace