/*******************************************************************************
In this do-file the final variables a cretaed in order to then conduct the randomization
********************************************************************************/
		
* ---------------------------------------------------------------------------- *
* ---------------------------------------------------------------------------- *
* 		              Variable creation for randomization                      *
* ---------------------------------------------------------------------------- *
* ---------------------------------------------------------------------------- *

/*******************************************************************************
	REQUIRES:  	"${prelim}/data_sample_2018_2019_2020_2021.dta"
				"${prelim}/health_cent_GPS.dta"	
	
	CREATES:	"${prelim}/hc_sample_2021_for_randomization.dta": dta ready for randomization
				
				WRITEN BY:  Michele Andreottola
*******************************************************************************/

/*******************************************************************************
              PART 1: Importing Pre-treatment sample data
********************************************************************************/

use          "${prelim}/data_sample_2018_2019_2020_2021.dta", clear


/*******************************************************************************
			PART 2: Now we want to understand whether data from 2021 is better in terms 
			of reporting compared to previous years. If the answer is yes, we will only
			use data from 2021 to establish balance between treatment and control
********************************************************************************/

* ~~~ Computes number of missing values per observation
egen nmis_alternat = rmiss2(coc_hc cop_hc diu_hc dmpa_im_hc impl_hc postinor_hc pres_f_hc pres_m_hc dmpa_im_tps sayana_tps) // this is really useful because if = 10 it means that no observations at all (all the 10 variables have missing values). So if you sum by Health center, you can get total number of missings over time.
*which increases if more months with missing and also if more variables with missing (both good qualities for our indicator). 

* The only caveat is that it is not clear whether a zero of quantities is translated into a missing value or not.
su coc_hc cop_hc diu_hc dmpa_im_hc impl_hc postinor_hc pres_f_hc pres_m_hc dmpa_im_tps sayana_tps, sep(0) // min value is 1
// So, if a health center has administerd 0 preservativ over a certain month, the variable pres_m_adm  would report a missing value, just as if the data had not been reported. In other word, it is impossible to differentiate between true missing values (data not reported) and zeros.

preserve 

	collapse (sum) tot_var_mi = nmis_alternat (mean) mean_var_mi = nmis_alternat, by(province district health_cent_id year) // here you get an indicator of how many variables have been reported as missing in each year. If a health center has always reported all the variables, then tot_var_mi = 0
	// if, on the other hand, a health centre in a certain year has never reported any variable in all the 12 months, tot_var_mi = 10*12 = 120. So the closer tot_var_mi is to 0, the better reporting quality of the health centre for the given year. 


	*to understand whether data from 2021 are better in terms of reporting, we get the mean number of missing values across all health centers by year
	collapse (sum) tot_var_mi (mean) mean_var_mi , by(year)

	list year tot_var_mi mean_var_mi
	/*
	  year   tot_var_mi   mean_var_mi 
	|----------------------------|
	| 2018       8195   4.948671 |
	| 2019       7990   4.824879 |
	| 2020       8103   4.893116 |
	| 2021       7902   4.771739 |
	*/

restore

*Above we have checked the number of missing values. However, it is impossible to differentiate between true missing values (data not reported) and zeros. Therefore, as a further check, we look at the number of months in which hc have never reported any data

gen all_alt_miss = . 
replace all_alt_miss = 1 if nmis_alternat == 10 // all_alt_miss = 1 means that all variables reffering to contraceptive are missing for that specific month
replace all_alt_miss = 0 if nmis_alternat < 10 // 0 means that at leat one variable reffering to contraceptive is not missing for that specific month
tab all_alt_miss, missing 

preserve

	collapse (sum) months_all_mi = all_alt_miss, by(health_cent_id year)
	tab months_all_mi 

	collapse (sum) months_all_mi (mean) avg_months_all_mi = months_all_mi, by(year)
	list year months_all_mi avg_months_all_mi

	/* The number of months with all missing values in terms of contraceptive administrations decreased substantially over time. 
		 +----------------------------+
		 | year   months~i   avg_mo~i |
		 |----------------------------|
	  1. | 2018        227   1.644928 |
	  2. | 2019        126   .9130435 |
	  3. | 2020         81   .5869565 |
	  4. | 2021          7   .0507246 
	*/			

restore 


/*******************************************************************************
              DECISION: Given the findings above, we conclude that data from 2021
			  are better in terms of reporting. Hence we will only focus on 2021 to 
			  evaluate balance between treatment and control
********************************************************************************/

keep if year == 2021

/*******************************************************************************
              PREREQUISITE FOR SELECTION IN THE STUDY SAMPLE:  
			  HC that have never reported any data on contraceptive administration 
			  in the last 12 months cannot be part of the study sample. 
			  Ratio: either they never report or they do not administer contraceptives 
			  at all
********************************************************************************/

preserve

	collapse (sum) tot_var_mi = nmis_alternat (mean) mean_var_mi = nmis_alternat, by(province district health_cent_id)

	gen share_mis_alt = mean_var_mi/10 *100

	recode share_mis_alt 0 = 0 0.1/9.9999 = 5 10/19.9999 = 15 20/29.9999 = 25 30/39.9999 = 35 40/49.9999 = 45 50/59.9999 = 55 60/69.9999 = 65 70/79.9999 = 75 80/89.9999 = 85 90/99.9999 = 95 100 = 100, generate(recoded_share)

	label define recoded_nmiss 0 "0%" 5 "Btw 0% and 10%" 15 "Btw 10% and 20%" 25 "Btw 20% and 30%" 35 "Btw 30% and 40%" 45 "Btw 40% and 50%" 55 "Btw 50% and 60%" 65 "Btw 60% and 70%" 75 "Btw 70% and 80%" 85 "Btw 80% and 90%" 95 "Btw 90% and 100%" 100 "100%"
	label values  recoded_share recoded_nmiss

	tab recoded_share 

	/*
		   RECODE of |
	   share_mis_alt |      Freq.     Percent        Cum.
	-----------------+-----------------------------------
	 Btw 30% and 40% |         24       17.39       17.39
	 Btw 40% and 50% |         61       44.20       61.59
	 Btw 50% and 60% |         40       28.99       90.58
	 Btw 60% and 70% |         11        7.97       98.55
	 Btw 70% and 80% |          2        1.45      100.00
	-----------------+-----------------------------------
			   Total |        138      100.00
	*/

	list health_cent_id if share_mis_alt == 100

	** There are no HC that have never reported any data: no HC gets excluded

restore


/*******************************************************************************
				PART 3: Now we merge geocoordinates variables, using another dataset
				provided by the government
				This dataset contains the province, district and name of health centers, 
				but it has different formatting of names sometimes.
				We will merge using string variables (not ideal but best we can do here). 
				To make sure that the merge captures all HC present in both datasets, 
				we need to make names consistent across the 2 datasets
				Also adds variable on Type of health facility (public vs private) and 
				whether it is located in rural vs urban area
********************************************************************************/

preserve // I am using preserve because I dont want to change the original names of HC present DHIS2

	foreach var of varlist province district commune health_cent {

	* Removing leading, trailing and internal multiple blanks *
	replace `var' = strtrim(stritrim(`var'))

	* Removing accents *
	replace `var' = ustrto(ustrnormalize(`var', "nfd"), "ascii", 2)

	* Converting all names into capital letters *
	replace `var' = strlower(`var')
	}

	replace province = proper(province)
	replace district = proper(district) 
	gen district_new = substr(district, 4, .)
	drop district
	rename district_new district
	order district, after(province)
	replace commune = proper(commune) 

	merge m:1 province district commune health_cent using "${prelim}/health_cent_GPS.dta", keepusing(Latitude Longitude Type Milieu)

	/*
		Result                      Number of obs
		-----------------------------------------
		Not matched                           850
			from master                       660  (_merge==1)
			from using                        190  (_merge==2)

		Matched                               996  (_merge==3)
		-----------------------------------------
	*/
	* 996/12 = 83 of our 138 health centers are included in the dataset shared by the gov. For these
	*HC we will have geoocordinates. The remainig 55 HC are not included in the dataset shared by the gov, therefore
	*for these HC we will not have any info on geolocation

	keep if _merge == 1 | _merge == 3 // we want to keep all health centers fro our sample. Those only included in using are not of interest

	bysort health_cent_id: keep if _n==1

	codebook Latitude
	tab Milieu
	tab Type // all public health centers

	tempfile geocoordin
	save `geocoordin'
	
restore


merge m:1 health_cent_id using `geocoordin', keepusing(Latitude Longitude Type Milieu)

/*
    Result                      Number of obs
    -----------------------------------------
    Not matched                             0
    Matched                             1,656  (_merge==3)
    -----------------------------------------
*/

drop nmis_alternat all_alt_miss _merge

 
 
/*******************************************************************************
				PART 4: Compute total number of contraceptives per month, 
				which we will use for stratification 
********************************************************************************/
 
egen tot_contracep = rowtotal(coc_hc cop_hc - sayana_tps)
label var tot_contracep "Total number of contraceptives administed per month"


* This command ignores missings, therefore the generated variable will have value zero if all the right-hand-side variables are missing (the same would happen if any of the variables had value zero, which is not the case here) 
su coc_hc cop_hc - sayana_tps, sep(0)
replace tot_contracep = . if tot_contracep == 0 


/*******************************************************************************
				PART 5: Dealing with missing values
********************************************************************************/
*DECISION: since we do not know if missing values are "zero" or if data have not been reported, we proceed as following:
*if no data on any contraceptive has been reported in a particular month, we assume that the monthly observation is missing.
*if, on the other hand, in a particular month, some variables have been reported and some are missing, we turn missing into zeros

foreach var of varlist coc_hc cop_hc diu_hc dmpa_im_hc impl_hc postinor_hc pres_f_hc pres_m_hc dmpa_im_tps sayana_tps {
	replace `var' = 0 if `var' == . & tot_contracep != .
}


/*******************************************************************************
				PART 6: Compute tot share of injectables over all contraceptives 
				administered per month, which we will use for stratification 
********************************************************************************/

gen share_inj = dmpa_im_hc/tot_contracep
label var share_inj "Share of injectables over total contraceptives administered"


/*******************************************************************************
				PART 7: Final data sample for RANDOMIZATION (based on 2021 data)
********************************************************************************/

collapse (mean) coc_hc cop_hc diu_hc dmpa_im_hc impl_hc postinor_hc pres_f_hc pres_m_hc dmpa_im_tps sayana_tps share_inj tot_contracep , by(health_cent_id province district commune health_cent)


save "${prelim}/hc_sample_2021_for_randomization.dta", replace



