/*******************************************************************************
In this do-file tha sample of health centers is randomized into treatment and control group
********************************************************************************/
		
* ---------------------------------------------------------------------------- *
* ---------------------------------------------------------------------------- *
*                           RANDOMIZATION DO-FILE                              *
*                                Burundi IE                                    *
* ---------------------------------------------------------------------------- *
* ---------------------------------------------------------------------------- *

/*******************************************************************************
	REQUIRES:  	"${prelim}/hc_sample_2021_for_randomization.dta"
	
	CREATES:	"${raw}/study sample/hc_treatment_status.dta": treatment assignement 
				
				WRITEN BY:  Michele Andreottola
*******************************************************************************/

/*******************************************************************************
             Importing data sample from 2021
********************************************************************************/
use "${prelim}/hc_sample_2021_for_randomization.dta", clear


/*******************************************************************************
			  STRATA:
			  Province
			  SHARE Inj (Low, High)
			  TOT Contr (Low, High)
********************************************************************************/
***Now we want to define a variable SHARE Inj (Low, High), based on the 50th percentile

*calculate 50th percentile of variable share_inj
centile share_inj, centile(50)
/*                                                          Binom. interp.   
    Variable |       Obs  Percentile    Centile        [95% conf. interval]
-------------+-------------------------------------------------------------
   share_inj |       138         50    .3359287        .2912181    .3911765
*/

centile tot_contracep, centile(50)

/*                                                          Binom. interp.   
    Variable |       Obs  Percentile    Centile        [95% conf. interval]
-------------+-------------------------------------------------------------
tot_contra~p |       138         50    287.0417        256.5408    325.2446
*/

*define a new variable with 2 categories: value of 1 if share of injectable is below 50th percentile, 2 if above or equal to 50th percentile
gen inject_dose = 1
replace inject_dose = 2 if share_inj >= 0.3359287
tab inject_dose

*define a new variable with 2 categories: value of 1 if tot contraceptives is below 50th percentile, 2  if above or equal to 50th percentile
gen contrac_adm = 1
replace contrac_adm = 2 if tot_contracep >= 287.0417
tab contrac_adm

label define med 1 "Low" 2 "High"
label values inject_dose med
label values contrac_adm med
label variable inject_dose "Indictor of avg monthly share of injectable above vs below median"
label variable contrac_adm "Indictor of avg monthly n contraceptive above vs below median"

*** Encode province --> to use as randomization strata
encode province, generate(province2)


/*******************************************************************************
              PART 3: RANDOMIZATION through RANDTREAT COMMAND 
********************************************************************************/

***stratified randomization

***3 variables used to define strata: province, share of injectables over total contraceptives administered (low, high), tot contraceptives administered (low, high)

*** Set seed (using random number)

randtreat, generate(rand_group) setseed(52668546) replace strata(province2 inject_dose contrac_adm) misfits(global) multiple(2)

tab rand_group
/*
  treatment |      Freq.     Percent        Cum.
------------+-----------------------------------
          0 |         68       50.00       50.00
          1 |         68       50.00      100.00
------------+-----------------------------------
      Total |        136      100.00
*/

egen strata = group(province2 inject_dose contrac_adm)
tab strata
label variable strata "Strata used in randomization: province, inject_dose, contrac_adm"
drop province2

/*
group(provi |
       nce2 |
inject_dose |
contrac_adm |
          ) |      Freq.     Percent        Cum.
------------+-----------------------------------
          1 |          2        1.45        1.45
          2 |          5        3.62        5.07
          3 |          4        2.90        7.97
          4 |          4        2.90       10.87
          5 |          2        1.45       12.32
          6 |          5        3.62       15.94
          7 |         10        7.25       23.19
          8 |          3        2.17       25.36
          9 |         18       13.04       38.41
         10 |         11        7.97       46.38
         11 |          5        3.62       50.00
         12 |          2        1.45       51.45
         13 |          5        3.62       55.07
         14 |         14       10.14       65.22
         15 |          1        0.72       65.94
         16 |          6        4.35       70.29
         17 |          1        0.72       71.01
         18 |          4        2.90       73.91
         19 |          6        4.35       78.26
         20 |         17       12.32       90.58
         21 |         13        9.42      100.00
------------+-----------------------------------
      Total |        138      100.00
*/


label define rand 0 "Control " 1 "Treatment"
label values rand_group rand
label variable rand_group "Indicator of health center randomized into Treatment"


label var coc_hc "(Monthly Avg, 2021) Quant Adm at HC - COC Pill"
label var cop_hc "(Monthly Avg, 2021) Quant Adm at HC - COP Pill"
label var diu_hc "(Monthly Avg, 2021) Quant Adm at HC - DIU"
label var dmpa_im_hc "(Monthly Avg, 2021) Quant Adm at HC - DMPA-IM"
label var impl_hc "(Monthly Avg, 2021) Quant Adm at HC - Implant"
label var postinor_hc "(Monthly Avg, 2021) Quant Adm at HC - Emergency pill"
label var pres_f_hc "(Monthly Avg, 2021) Quant Adm at HC - Female condom"
label var pres_m_hc "(Monthly Avg, 2021) Quant Adm at HC - Condom"
label var dmpa_im_tps "(Monthly Avg, 2021) Quant Adm by TPS - DMPA-IM"
label var sayana_tps "(Monthly Avg, 2021) Quant Adm by TPS - DMPA-SC (Sayana)" // we have not yet added to this data info on total Sayana Press administred (new variable sent later by the government)
label var tot_contracep "(Monthly Avg, 2021) Quant Adm - Total"
label var share_inj "(Monthly Avg, 2021) Quant Adm - Share of injectables"

save "${raw}/study sample/hc_treatment_status.dta", replace



/* Checking if stratification worked: it did!

/* ~~ Both Treatment and Control groups have 
- around 50% above vs below the median of total n of contraceptive administered and % injectables
- similar shares in each province as in the original sample data */

tab province, gen(prov)
tab inject_dose, gen(inject_level)
tab contrac_adm, gen(contrac_adm_level)

su inject_level? contrac_adm_level? prov?, sep(0)
/*
    Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
inject_lev~1 |        138          .5    .5018215          0          1
inject_lev~2 |        138          .5    .5018215          0          1
contrac_ad~1 |        138          .5    .5018215          0          1
contrac_ad~2 |        138          .5    .5018215          0          1
       prov1 |        138    .1086957    .3123909          0          1
       prov2 |        138    .1449275    .3533102          0          1
       prov3 |        138    .2608696    .4407086          0          1
       prov4 |        138    .1884058    .3924604          0          1
       prov5 |        138    .0362319    .1875474          0          1
       prov6 |        138    .2608696    .4407086          0          1
*/

bys rand_group: su inject_level? contrac_adm_level? prov?, sep(0)
/*
-> rand_group = Control

    Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
inject_lev~1 |         69    .4782609    .5031868          0          1
inject_lev~2 |         69    .5217391    .5031868          0          1
contrac_ad~1 |         69    .5072464    .5036102          0          1
contrac_ad~2 |         69    .4927536    .5036102          0          1
       prov1 |         69     .115942    .3225009          0          1
       prov2 |         69    .1449275    .3546068          0          1
       prov3 |         69    .2608696    .4423259          0          1
       prov4 |         69    .1884058    .3939006          0          1
       prov5 |         69    .0289855    .1689948          0          1
       prov6 |         69    .2608696    .4423259          0          1

---------------------------------------------------------------------------------------------
-> rand_group = Treatment

    Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
inject_lev~1 |         69    .5217391    .5031868          0          1
inject_lev~2 |         69    .4782609    .5031868          0          1
contrac_ad~1 |         69    .4927536    .5036102          0          1
contrac_ad~2 |         69    .5072464    .5036102          0          1
       prov1 |         69    .1014493    .3041346          0          1
       prov2 |         69    .1449275    .3546068          0          1
       prov3 |         69    .2608696    .4423259          0          1
       prov4 |         69    .1884058    .3939006          0          1
       prov5 |         69    .0434783    .2054251          0          1
       prov6 |         69    .2608696    .4423259          0          1
*/
*/